@@ -1,8 +1,8 @@
 #include "Bdef.h"
 
-void BI_BlacsAbort(int ErrNo)
+void BI_BlacsAbort(Int ErrNo)
 {
-   int ierr;
+   Int ierr;
    fflush(stderr);
    fflush(stdout);
    ierr=MPI_Abort(MPI_COMM_WORLD, ErrNo);
