@@ -1,10 +1,10 @@
 #include "Bdef.h"
 
-void BI_ivvamn2(int N, char *vec1, char *vec2)
+void BI_ivvamn2(Int N, char *vec1, char *vec2)
 {
-   int k;
-   int *v1=(int*)vec1, *v2=(int*)vec2;
-   int diff;
+   Int k;
+   Int *v1=(Int*)vec1, *v2=(Int*)vec2;
+   Int diff;
 
    for (k=0; k != N; k++)
    {
