@@ -15,6 +15,16 @@
 #include <stdarg.h>
 #include <mpi.h>
 
+/*
+ * Integer types used by BLACS
+ */
+#ifndef Int
+#define Int int
+#endif
+#ifndef MpiInt
+#define MpiInt int
+#endif
+
 /*
  * These macros define the naming strategy needed for a fortran
  * routine to call a C routine, and whether to build so they may be
