@@ -17,23 +17,23 @@
 #include "PBblas.h"
 
 #ifdef __STDC__
-void psger_( int * M, int * N, float * ALPHA,
-             float * X, int * IX, int * JX, int * DESCX, int * INCX,
-             float * Y, int * IY, int * JY, int * DESCY, int * INCY,
-             float * A, int * IA, int * JA, int * DESCA )
+void psger_( Int * M, Int * N, float * ALPHA,
+             float * X, Int * IX, Int * JX, Int * DESCX, Int * INCX,
+             float * Y, Int * IY, Int * JY, Int * DESCY, Int * INCY,
+             float * A, Int * IA, Int * JA, Int * DESCA )
 #else
 void psger_( M, N, ALPHA, X, IX, JX, DESCX, INCX, Y, IY, JY, DESCY,
              INCY, A, IA, JA, DESCA )
 /*
 *  .. Scalar Arguments ..
 */
-   int            * IA, * INCX, * INCY, * IX, * IY, * JA, * JX, * JY,
+   Int            * IA, * INCX, * INCY, * IX, * IY, * JA, * JX, * JY,
                   * M, * N;
    float          * ALPHA;
 /*
 *  .. Array Arguments ..
 */
-   int            * DESCA, * DESCX, * DESCY;
+   Int            * DESCA, * DESCX, * DESCY;
    float          * A, * X, * Y;
 #endif
 {
@@ -216,14 +216,14 @@ void psger_( M, N, ALPHA, X, IX, JX, DESCX, INCX, Y, IY, JY, DESCY,
 /*
 *  .. Local Scalars ..
 */
-   int            Acol, Ai, Aii, Aimb1, Ainb1, Aj, Ajj, Ald, Amb, Amp, Anb,
+   Int            Acol, Ai, Aii, Aimb1, Ainb1, Aj, Ajj, Ald, Amb, Amp, Anb,
                   Anq, Arow, XAfr, Xi, Xj, YAfr, Yi, Yj, ctxt, info, ione=1,
                   mycol, myrow, npcol, nprow;
    PBTYP_T        * type;
 /*
 *  .. Local Arrays ..
 */
-   int            Ad[DLEN_], Ad0[DLEN_], XAd[DLEN_], Xd[DLEN_], YAd[DLEN_],
+   Int            Ad[DLEN_], Ad0[DLEN_], XAd[DLEN_], Xd[DLEN_], YAd[DLEN_],
                   Yd[DLEN_];
    char           * XA = NULL, * YA = NULL;
 /* ..
@@ -286,7 +286,7 @@ void psger_( M, N, ALPHA, X, IX, JX, DESCX, INCX, Y, IY, JY, DESCY,
    if( ( Amp > 0 ) && ( Anq > 0 ) )
    {
       sger_( &Amp, &Anq, ((char *) ALPHA), XA, &ione, YA, &YAd[LLD_],
-             ((char *) (A+(Aii+Ajj*Ald))), &Ald );
+             ((char *)Mptr(A,Aii,Ajj,Ald,1)), &Ald );
    }
    if( XAfr ) free( XA );
    if( YAfr ) free( YA );
