@@ -75,20 +75,20 @@
 #define Clacpy Csgelacpy
 void  Clacpy();
 typedef struct {
-  int   desctype;
-  int   ctxt;
-  int   m;
-  int   n;
-  int   nbrow;
-  int   nbcol;
-  int   sprow;
-  int   spcol;
-  int   lda;
+  Int   desctype;
+  Int   ctxt;
+  Int   m;
+  Int   n;
+  Int   nbrow;
+  Int   nbcol;
+  Int   sprow;
+  Int   spcol;
+  Int   lda;
 }     MDESC;
 #define BLOCK_CYCLIC_2D 1
 typedef struct {
-  int   lstart;
-  int   len;
+  Int   lstart;
+  Int   len;
 }     IDESC;
 #define SHIFT(row,sprow,nbrow) ((row)-(sprow)+ ((row) >= (sprow) ? 0 : (nbrow)))
 #define max(A,B) ((A)>(B)?(A):(B))
@@ -102,7 +102,7 @@ typedef struct {
 #endif
 /* Cblacs */
 extern void Cblacs_pcoord();
-extern int Cblacs_pnum();
+extern Int Cblacs_pnum();
 extern void Csetpvmtids();
 extern void Cblacs_get();
 extern void Cblacs_pinfo();
@@ -123,12 +123,12 @@ extern void Csgerv2d();
 /* lapack */
 void  slacpy_();
 /* aux fonctions */
-extern int localindice();
+extern Int localindice();
 extern void *mr2d_malloc();
-extern int ppcm();
-extern int localsize();
-extern int memoryblocksize();
-extern int changeorigin();
+extern Int ppcm();
+extern Int localsize();
+extern Int memoryblocksize();
+extern Int changeorigin();
 extern void paramcheck();
 /* tools and others function */
 #define scanD0 sgescanD0
@@ -140,7 +140,7 @@ extern void scanD0();
 extern void dispmat();
 extern void setmemory();
 extern void freememory();
-extern int scan_intervals();
+extern Int scan_intervals();
 extern void Cpsgemr2do();
 extern void Cpsgemr2d();
 /* some defines for Cpsgemr2do */
@@ -161,12 +161,10 @@ extern void Cpsgemr2d();
 /* initblock: intialize the local part of a matrix with random data (well,
  * not very random) */
 static2 void
-initblock(block, m, n)
-  float *block;
-  int   m, n;
+initblock(float *block, Int m, Int n)
 {
   float *pdata;
-  int   i;
+  Int   i;
   pdata = block;
   for (i = 0; i < m * n; i++, pdata++) {
     (*pdata) = i;
@@ -188,10 +186,10 @@ va_dcl
   FILE *f;
 #endif
   va_list ap;
-  int   i;
-  static int nbline;
+  Int   i;
+  static Int nbline;
   char *ptr, *next;
-  int  *var;
+  Int  *var;
   static char buffer[200];
 #ifdef __STDC__
   va_start(ap, f);
@@ -208,7 +206,7 @@ va_dcl
     nbline += 1;
   } while (buffer[0] == '#');
   ptr = buffer;
-  var = va_arg(ap, int *);
+  var = va_arg(ap, Int *);
   while (var != NULL) {
     *var = strtol(ptr, &next, 10);
     if (ptr == next) {
@@ -216,16 +214,14 @@ va_dcl
       exit(1);
     }
     ptr = next;
-    var = va_arg(ap, int *);
+    var = va_arg(ap, Int *);
   }
   va_end(ap);
 }
 void 
-initforpvm(argc, argv)
-  int   argc;
-  char *argv[];
+initforpvm(Int argc, char *argv[])
 {
-  int   pnum, nproc;
+  Int   pnum, nproc;
   Cblacs_pinfo(&pnum, &nproc);
   if (nproc < 1) {	/* we are with PVM */
     if (pnum == 0) {
@@ -240,32 +236,30 @@ initforpvm(argc, argv)
   }
 }
 int
-main(argc, argv)
-  int   argc;
-  char *argv[];
+main(int argc, char *argv[])
 {
   /* We initialize the data-block on the current processor, then redistribute
    * it, and perform the inverse redistribution  to compare the local memory
    * with the initial one. */
   /* Data file */
   FILE *fp;
-  int   nbre, nbremax;
+  Int   nbre, nbremax;
   /* Data distribution 0 parameters */
-  int   p0,	/* # of rows in the processor grid */
+  Int   p0,	/* # of rows in the processor grid */
         q0;	/* # of columns in the processor grid */
   /* Data distribution 1 parameters */
-  int   p1, q1;
+  Int   p1, q1;
   /* # of parameter to be read on the keyboard */
 #define nbparameter 24
   /* General variables */
-  int   blocksize0;
-  int   mypnum, nprocs;
-  int   parameters[nbparameter], nberrors;
-  int   i;
-  int   ia, ja, ib, jb, m, n;
-  int   gcontext, context0, context1;
-  int   myprow1, myprow0, mypcol0, mypcol1;
-  int   dummy;
+  Int   blocksize0;
+  Int   mypnum, nprocs;
+  Int   parameters[nbparameter], nberrors;
+  Int   i;
+  Int   ia, ja, ib, jb, m, n;
+  Int   gcontext, context0, context1;
+  Int   myprow1, myprow0, mypcol0, mypcol1;
+  Int   dummy;
   MDESC ma, mb;
   float *ptrmyblock, *ptrsavemyblock, *ptrmyblockcopy, *ptrmyblockvide;
 #ifdef UsingMpiBlacs
@@ -280,8 +274,8 @@ main(argc, argv)
   /* Read physical parameters */
   Cblacs_pinfo(&mypnum, &nprocs);
   /* initialize BLACS for the parameter communication */
-  Cblacs_get(0, 0, &gcontext);
-  Cblacs_gridinit(&gcontext, "R", nprocs, 1);
+  Cblacs_get((Int)0, (Int)0, &gcontext);
+  Cblacs_gridinit(&gcontext, "R", nprocs, (Int)1);
   Cblacs_gridinfo(gcontext, &dummy, &dummy, &mypnum, &dummy);
   if (mypnum == 0) {
     if ((fp = fopen("GEMR2D.dat", "r")) == NULL) {
@@ -292,9 +286,9 @@ main(argc, argv)
     getparam(fp, &nbre, NULL);
     printf("////////// %d tests \n\n", nbre);
     parameters[0] = nbre;
-    Cigebs2d(gcontext, "All", "H", 1, 1, parameters, 1);
+    Cigebs2d(gcontext, "All", "H", (Int)1, (Int)1, parameters, (Int)1);
   } else {
-    Cigebr2d(gcontext, "All", "H", 1, 1, parameters, 1, 0, 0);
+    Cigebr2d(gcontext, "All", "H", (Int)1, (Int)1, parameters, (Int)1, (Int)0, (Int)0);
     nbre = parameters[0];
   };
   if (mypnum == 0) {
@@ -312,7 +306,7 @@ m1  n1  sr1 sc1 i1  j1  p1  q1 nbr1 nbc1\n\n");
      * grid at each iteration */
     /* Read processors grid and matrices parameters */
     if (mypnum == 0) {
-      int   u, d;
+      Int   u, d;
       getparam(fp,
 	       &m, &n,
 	       &ma.m, &ma.n, &ma.sprow, &ma.spcol,
@@ -357,9 +351,9 @@ m1  n1  sr1 sc1 i1  j1  p1  q1 nbr1 nbc1\n\n");
       parameters[19] = n;
       parameters[20] = mb.m;
       parameters[21] = mb.n;
-      Cigebs2d(gcontext, "All", "H", 1, nbparameter, parameters, 1);
+      Cigebs2d(gcontext, "All", "H", (Int)1, nbparameter, parameters, (Int)1);
     } else {
-      Cigebr2d(gcontext, "All", "H", 1, nbparameter, parameters, 1, 0, 0);
+      Cigebr2d(gcontext, "All", "H", (Int)1, nbparameter, parameters, (Int)1, (Int)0, (Int)0);
       p0 = parameters[0];
       q0 = parameters[1];
       ma.nbrow = parameters[2];
@@ -385,9 +379,9 @@ m1  n1  sr1 sc1 i1  j1  p1  q1 nbr1 nbc1\n\n");
       ma.desctype = BLOCK_CYCLIC_2D;
       mb.desctype = BLOCK_CYCLIC_2D;
     };
-    Cblacs_get(0, 0, &context0);
+    Cblacs_get((Int)0, (Int)0, &context0);
     Cblacs_gridinit(&context0, "R", p0, q0);
-    Cblacs_get(0, 0, &context1);
+    Cblacs_get((Int)0, (Int)0, &context1);
     Cblacs_gridinit(&context1, "R", p1, q1);
     Cblacs_gridinfo(context0, &dummy, &dummy, &myprow0, &mypcol0);
     if (myprow0 >= p0 || mypcol0 >= q0)
@@ -435,8 +429,8 @@ m1  n1  sr1 sc1 i1  j1  p1  q1 nbr1 nbc1\n\n");
     if (myprow0 >= 0 && mypcol0 >= 0) {
       /* only for the processors that do have data at the begining */
       for (i = 0; i < blocksize0; i++) {
-	int   li, lj, gi, gj;
-	int   in;
+	Int   li, lj, gi, gj;
+	Int   in;
 	in = 1;
 	li = i % ma.lda;
 	lj = i / ma.lda;
@@ -463,7 +457,7 @@ Number of redistribution errors = %d \n",
       }
     }
     /* Look at the errors on all the processors at this point. */
-    Cigsum2d(gcontext, "All", "H", 1, 1, &nberrors, 1, 0, 0);
+    Cigsum2d(gcontext, "All", "H", (Int)1, (Int)1, &nberrors, (Int)1, (Int)0, (Int)0);
     if (mypnum == 0)
       if (nberrors)
 	printf("  => Total number of redistribution errors = %d \n",
@@ -488,6 +482,6 @@ Number of redistribution errors = %d \n",
   if (mypnum == 0) {
     fclose(fp);
   };
-  Cblacs_exit(0);
+  Cblacs_exit((Int)0);
   return 0;
 }/* main */
