@@ -1,10 +1,9 @@
       SUBROUTINE PCLARZB( SIDE, TRANS, DIRECT, STOREV, M, N, K, L, V,
      $                    IV, JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     March 14, 2000
+*  -- ScaLAPACK auxiliary routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          DIRECT, SIDE, STOREV, TRANS
@@ -243,7 +242,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_ABORT, BLACS_GRIDINFO, CGEBR2D,
      $                   CGEBS2D, CGEMM, CGSUM2D, CLACGV,
-     $                   CLACPY, CLASET, CTRBR2D, CTRBS2D,
+     $                   CLAMOV, CLASET, CTRBR2D, CTRBS2D,
      $                   CTRMM, INFOG2L, PBCMATADD, PBCTRAN,
      $                   PB_TOPGET, PXERBLA
 *     ..
@@ -381,10 +380,10 @@
 *
          IF( MYROW.EQ.IVROW ) THEN
             IF( MYCOL.EQ.IVCOL ) THEN
-               CALL CLACPY( 'All', K, MQV, V( IOFFV ), LDV,
+               CALL CLAMOV( 'All', K, MQV, V( IOFFV ), LDV,
      $                      WORK( IPW+ICOFFV*LW ), LW )
             ELSE
-               CALL CLACPY( 'All', K, MQV, V( IOFFV ), LDV,
+               CALL CLAMOV( 'All', K, MQV, V( IOFFV ), LDV,
      $                      WORK( IPW ), LW )
             END IF
          END IF
@@ -517,7 +516,7 @@
             IF( MYCOL.EQ.IVCOL )
      $         CALL CTRBS2D( ICTXT, 'Columnwise', COLBTOP, 'Lower',
      $                       'Non unit', K, K, T, MBV )
-            CALL CLACPY( 'All', K, NQC2, V( IOFFV ), LDV, WORK( IPV ),
+            CALL CLAMOV( 'All', K, NQC2, V( IOFFV ), LDV, WORK( IPV ),
      $                   LV )
          ELSE
             CALL CGEBR2D( ICTXT, 'Columnwise', COLBTOP, K, NQC2,
