@@ -1,10 +1,9 @@
       SUBROUTINE PDPBTRSV( UPLO, TRANS, N, BW, NRHS, A, JA, DESCA, B,
      $                     IB, DESCB, AF, LAF, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 3, 2000
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS, UPLO
@@ -394,7 +393,7 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DESC_CONVERT,
-     $                   DGEMM, DGERV2D, DGESD2D, DLACPY, DMATADD,
+     $                   DGEMM, DGERV2D, DGESD2D, DLAMOV, DMATADD,
      $                   DTBTRS, DTRMM, DTRTRS, GLOBCHK, PXERBLA,
      $                   RESHAPE
 *     ..
@@ -762,7 +761,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-               CALL DLACPY( 'N', BW, NRHS,
+               CALL DLAMOV( 'N', BW, NRHS,
      $                      B( PART_OFFSET+ODD_SIZE-BW+1 ), LLDB,
      $                      WORK( 1 ), BW )
 *
@@ -1086,7 +1085,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-               CALL DLACPY( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
+               CALL DLAMOV( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
      $                      LLDB, WORK( 1+BW-BW ), BW )
 *
                CALL DTRMM( 'L', 'U', 'T', 'N', BW, NRHS, -ONE,
@@ -1136,7 +1135,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-               CALL DLACPY( 'N', BW, NRHS,
+               CALL DLAMOV( 'N', BW, NRHS,
      $                      B( PART_OFFSET+ODD_SIZE-BW+1 ), LLDB,
      $                      WORK( 1 ), BW )
 *
@@ -1460,7 +1459,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-               CALL DLACPY( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
+               CALL DLAMOV( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
      $                      LLDB, WORK( 1+BW-BW ), BW )
 *
                CALL DTRMM( 'L', 'L', 'N', 'N', BW, NRHS, -ONE,
