@@ -1,12 +1,10 @@
       SUBROUTINE PDPTTRF( N, D, E, JA, DESCA, AF, LAF, WORK, LWORK,
      $                    INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     April 3, 2000
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, JA, LAF, LWORK, N
@@ -344,19 +342,18 @@
 *
 *  Code Developer: Andrew J. Cleary, University of Tennessee.
 *    Current address: Lawrence Livermore National Labs.
-*  This version released: May, 1997.
 *
 *  =====================================================================
 *
-*     ..
 *     .. Parameters ..
-      DOUBLE PRECISION   ONE, ZERO
+      DOUBLE PRECISION   ONE
       PARAMETER          ( ONE = 1.0D+0 )
+      DOUBLE PRECISION   ZERO
       PARAMETER          ( ZERO = 0.0D+0 )
       INTEGER            INT_ONE
       PARAMETER          ( INT_ONE = 1 )
       INTEGER            DESCMULT, BIGNUM
-      PARAMETER          (DESCMULT = 100, BIGNUM = DESCMULT * DESCMULT)
+      PARAMETER          ( DESCMULT = 100, BIGNUM = DESCMULT*DESCMULT )
       INTEGER            BLOCK_CYCLIC_2D, CSRC_, CTXT_, DLEN_, DTYPE_,
      $                   LLD_, MB_, M_, NB_, N_, RSRC_
       PARAMETER          ( BLOCK_CYCLIC_2D = 1, DLEN_ = 9, DTYPE_ = 1,
@@ -375,19 +372,17 @@
       INTEGER            DESCA_1XP( 7 ), PARAM_CHECK( 7, 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GET, BLACS_GRIDEXIT, BLACS_GRIDINFO,
-     $                   DAXPY, DESC_CONVERT, DGEMM, DGERV2D, DGESD2D,
-     $                   DLACPY, DLATCPY, DPBTRF, DPOTRF, DSYRK, DTBTRS,
-     $                   DTRMM, DTRRV2D, DTRSD2D, DTRSM, DTRTRS,
-     $                   GLOBCHK, PXERBLA, RESHAPE
+      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DESC_CONVERT,
+     $                   DGERV2D, DGESD2D, DPTTRF, DPTTRSV, DTRRV2D,
+     $                   DTRSD2D, GLOBCHK, IGAMX2D, IGEBR2D, IGEBS2D,
+     $                   PXERBLA, RESHAPE
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAME
       INTEGER            NUMROC
-      EXTERNAL           LSAME, NUMROC
+      EXTERNAL           NUMROC
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ICHAR, MIN, MOD
+      INTRINSIC          DBLE, MOD
 *     ..
 *     .. Executable Statements ..
 *
@@ -401,18 +396,18 @@
       DESCA_1XP( 1 ) = 501
 *
       TEMP = DESCA( DTYPE_ )
-      IF( TEMP .EQ. 502 ) THEN
+      IF( TEMP.EQ.502 ) THEN
 *        Temporarily set the descriptor type to 1xP type
          DESCA( DTYPE_ ) = 501
-      ENDIF
+      END IF
 *
       CALL DESC_CONVERT( DESCA, DESCA_1XP, RETURN_CODE )
 *
       DESCA( DTYPE_ ) = TEMP
 *
-      IF( RETURN_CODE .NE. 0) THEN
-         INFO = -( 5*100 + 2 )
-      ENDIF
+      IF( RETURN_CODE.NE.0 ) THEN
+         INFO = -( 5*100+2 )
+      END IF
 *
 *     Get values out of descriptor for use in code.
 *
@@ -426,62 +421,58 @@
 *
 *
       CALL BLACS_GRIDINFO( ICTXT, NPROW, NPCOL, MYROW, MYCOL )
-      NP = NPROW * NPCOL
+      NP = NPROW*NPCOL
 *
 *
 *
-      IF( LWORK .LT. -1) THEN
+      IF( LWORK.LT.-1 ) THEN
          INFO = -9
-      ELSE IF ( LWORK .EQ. -1 ) THEN
+      ELSE IF( LWORK.EQ.-1 ) THEN
          IDUM3 = -1
       ELSE
          IDUM3 = 1
-      ENDIF
+      END IF
 *
-      IF( N .LT. 0 ) THEN
+      IF( N.LT.0 ) THEN
          INFO = -1
-      ENDIF
+      END IF
 *
-      IF( N+JA-1 .GT. STORE_N_A ) THEN
-         INFO = -( 5*100 + 6 )
-      ENDIF
+      IF( N+JA-1.GT.STORE_N_A ) THEN
+         INFO = -( 5*100+6 )
+      END IF
 *
 *     Argument checking that is specific to Divide & Conquer routine
 *
-      IF( NPROW .NE. 1 ) THEN
+      IF( NPROW.NE.1 ) THEN
          INFO = -( 5*100+2 )
-      ENDIF
+      END IF
 *
-      IF( N .GT. NP*NB-MOD( JA-1, NB )) THEN
+      IF( N.GT.NP*NB-MOD( JA-1, NB ) ) THEN
          INFO = -( 1 )
-         CALL PXERBLA( ICTXT,
-     $      'PDPTTRF, D&C alg.: only 1 block per proc',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PDPTTRF, D&C alg.: only 1 block per proc'
+     $                 , -INFO )
          RETURN
-      ENDIF
+      END IF
 *
-      IF((JA+N-1.GT.NB) .AND. ( NB.LT.2*INT_ONE )) THEN
+      IF( ( JA+N-1.GT.NB ) .AND. ( NB.LT.2*INT_ONE ) ) THEN
          INFO = -( 5*100+4 )
-         CALL PXERBLA( ICTXT,
-     $      'PDPTTRF, D&C alg.: NB too small',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PDPTTRF, D&C alg.: NB too small', -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *
 *     Check auxiliary storage size
 *
-      LAF_MIN = (12*NPCOL + 3*NB)
+      LAF_MIN = ( 12*NPCOL+3*NB )
 *
-      IF( LAF .LT. LAF_MIN ) THEN
+      IF( LAF.LT.LAF_MIN ) THEN
          INFO = -7
 *        put minimum value of laf into AF( 1 )
          AF( 1 ) = LAF_MIN
-         CALL PXERBLA( ICTXT,
-     $      'PDPTTRF: auxiliary storage error ',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PDPTTRF: auxiliary storage error ',
+     $                 -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *     Check worksize
 *
@@ -489,33 +480,31 @@
 *
       WORK( 1 ) = WORK_SIZE_MIN
 *
-      IF( LWORK .LT. WORK_SIZE_MIN ) THEN
-         IF( LWORK .NE. -1 ) THEN
-           INFO = -9
-           CALL PXERBLA( ICTXT,
-     $      'PDPTTRF: worksize error ',
-     $      -INFO )
-         ENDIF
+      IF( LWORK.LT.WORK_SIZE_MIN ) THEN
+         IF( LWORK.NE.-1 ) THEN
+            INFO = -9
+            CALL PXERBLA( ICTXT, 'PDPTTRF: worksize error ', -INFO )
+         END IF
          RETURN
-      ENDIF
+      END IF
 *
 *     Pack params and positions into arrays for global consistency check
 *
-      PARAM_CHECK(  7, 1 ) = DESCA(5)
-      PARAM_CHECK(  6, 1 ) = DESCA(4)
-      PARAM_CHECK(  5, 1 ) = DESCA(3)
-      PARAM_CHECK(  4, 1 ) = DESCA(1)
-      PARAM_CHECK(  3, 1 ) = JA
-      PARAM_CHECK(  2, 1 ) = N
-      PARAM_CHECK(  1, 1 ) = IDUM3
+      PARAM_CHECK( 7, 1 ) = DESCA( 5 )
+      PARAM_CHECK( 6, 1 ) = DESCA( 4 )
+      PARAM_CHECK( 5, 1 ) = DESCA( 3 )
+      PARAM_CHECK( 4, 1 ) = DESCA( 1 )
+      PARAM_CHECK( 3, 1 ) = JA
+      PARAM_CHECK( 2, 1 ) = N
+      PARAM_CHECK( 1, 1 ) = IDUM3
 *
-      PARAM_CHECK(  7, 2 ) = 505
-      PARAM_CHECK(  6, 2 ) = 504
-      PARAM_CHECK(  5, 2 ) = 503
-      PARAM_CHECK(  4, 2 ) = 501
-      PARAM_CHECK(  3, 2 ) = 4
-      PARAM_CHECK(  2, 2 ) = 1
-      PARAM_CHECK(  1, 2 ) = 9
+      PARAM_CHECK( 7, 2 ) = 505
+      PARAM_CHECK( 6, 2 ) = 504
+      PARAM_CHECK( 5, 2 ) = 503
+      PARAM_CHECK( 4, 2 ) = 501
+      PARAM_CHECK( 3, 2 ) = 4
+      PARAM_CHECK( 2, 2 ) = 1
+      PARAM_CHECK( 1, 2 ) = 9
 *
 *     Want to find errors with MIN( ), so if no error, set it to a big
 *     number. If there already is an error, multiply by the the
@@ -526,20 +515,20 @@
       ELSE IF( INFO.LT.-DESCMULT ) THEN
          INFO = -INFO
       ELSE
-         INFO = -INFO * DESCMULT
+         INFO = -INFO*DESCMULT
       END IF
 *
 *     Check consistency across processors
 *
-      CALL GLOBCHK( ICTXT, 7, PARAM_CHECK, 7,
-     $              PARAM_CHECK( 1, 3 ), INFO )
+      CALL GLOBCHK( ICTXT, 7, PARAM_CHECK, 7, PARAM_CHECK( 1, 3 ),
+     $              INFO )
 *
 *     Prepare output: set info = 0 if no error, and divide by DESCMULT
 *     if error is not in a descriptor entry.
 *
       IF( INFO.EQ.BIGNUM ) THEN
          INFO = 0
-      ELSE IF( MOD( INFO, DESCMULT ) .EQ. 0 ) THEN
+      ELSE IF( MOD( INFO, DESCMULT ).EQ.0 ) THEN
          INFO = -INFO / DESCMULT
       ELSE
          INFO = -INFO
@@ -559,15 +548,15 @@
 *     Adjust addressing into matrix space to properly get into
 *        the beginning part of the relevant data
 *
-      PART_OFFSET = NB*( (JA-1)/(NPCOL*NB) )
+      PART_OFFSET = NB*( ( JA-1 ) / ( NPCOL*NB ) )
 *
-      IF ( (MYCOL-CSRC) .LT. (JA-PART_OFFSET-1)/NB ) THEN
+      IF( ( MYCOL-CSRC ).LT.( JA-PART_OFFSET-1 ) / NB ) THEN
          PART_OFFSET = PART_OFFSET + NB
-      ENDIF
+      END IF
 *
-      IF ( MYCOL .LT. CSRC ) THEN
+      IF( MYCOL.LT.CSRC ) THEN
          PART_OFFSET = PART_OFFSET - NB
-      ENDIF
+      END IF
 *
 *     Form a new BLACS grid (the "standard form" grid) with only procs
 *        holding part of the matrix, of size 1xNP where NP is adjusted,
@@ -575,7 +564,7 @@
 *
 *     First processor to hold part of the matrix:
 *
-      FIRST_PROC = MOD( ( JA-1 )/NB+CSRC, NPCOL )
+      FIRST_PROC = MOD( ( JA-1 ) / NB+CSRC, NPCOL )
 *
 *     Calculate new JA one while dropping off unused processors.
 *
@@ -584,12 +573,12 @@
 *     Save and compute new value of NP
 *
       NP_SAVE = NP
-      NP = ( JA_NEW+N-2 )/NB + 1
+      NP = ( JA_NEW+N-2 ) / NB + 1
 *
 *     Call utility routine that forms "standard-form" grid
 *
-      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE,
-     $              FIRST_PROC, INT_ONE, NP )
+      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE, FIRST_PROC,
+     $              INT_ONE, NP )
 *
 *     Use new context from standard grid as context.
 *
@@ -603,9 +592,9 @@
 *
 *     Drop out processors that do not have part of the matrix.
 *
-      IF( MYROW .LT. 0 ) THEN
-         GOTO 1234
-      ENDIF
+      IF( MYROW.LT.0 ) THEN
+         GO TO 90
+      END IF
 *
 *     ********************************
 *     Values reused throughout routine
@@ -620,24 +609,24 @@
 *
 *     Offset in columns to beginning of main partition in each proc
 *
-      IF ( MYCOL .EQ. 0 ) THEN
-        PART_OFFSET = PART_OFFSET+MOD( JA_NEW-1, PART_SIZE )
-        MY_NUM_COLS = MY_NUM_COLS - MOD(JA_NEW-1, PART_SIZE )
-      ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         PART_OFFSET = PART_OFFSET + MOD( JA_NEW-1, PART_SIZE )
+         MY_NUM_COLS = MY_NUM_COLS - MOD( JA_NEW-1, PART_SIZE )
+      END IF
 *
 *     Size of main (or odd) partition in each processor
 *
       ODD_SIZE = MY_NUM_COLS
-      IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
          ODD_SIZE = ODD_SIZE - INT_ONE
-      ENDIF
+      END IF
 *
 *
 *       Zero out space for fillin
 *
-        DO 10  I=1, LAF_MIN
-          AF( I ) = ZERO
-   10   CONTINUE
+      DO 10 I = 1, LAF_MIN
+         AF( I ) = ZERO
+   10 CONTINUE
 *
 *     Begin main code
 *
@@ -647,79 +636,79 @@
 ********************************************************************
 *
 *
-        IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
 *         Transfer last triangle D_i of local matrix to next processor
 *         which needs it to calculate fillin due to factorization of
 *         its main (odd) block A_i.
 *         Overlap the send with the factorization of A_i.
 *
-          CALL DTRSD2D( ICTXT, 'U', 'N', 1, 1,
-     $                  E( PART_OFFSET+ODD_SIZE+1 ), LLDA-1, 0,
-     $                  MYCOL+1 )
+         CALL DTRSD2D( ICTXT, 'U', 'N', 1, 1,
+     $                 E( PART_OFFSET+ODD_SIZE+1 ), LLDA-1, 0, MYCOL+1 )
 *
-        ENDIF
+      END IF
 *
 *
 *       Factor main partition A_i = L_i {L_i}^T in each processor
 *       Or A_i = {U_i}^T {U_i} if E is the upper superdiagonal
 *
-        CALL DPTTRF( ODD_SIZE, D( PART_OFFSET+1 ), E( PART_OFFSET+1 ),
-     $                    INFO )
+      CALL DPTTRF( ODD_SIZE, D( PART_OFFSET+1 ), E( PART_OFFSET+1 ),
+     $             INFO )
 *
-        IF( INFO.NE.0 ) THEN
-           INFO = MYCOL+1
-           GOTO 1500
-        ENDIF
+      IF( INFO.NE.0 ) THEN
+         INFO = MYCOL + 1
+         GO TO 20
+      END IF
 *
 *
-        IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
 *         Apply factorization to odd-even connection block B_i
 *
 *
 *         Perform the triangular system solve {L_i}{{B'}_i}^T = {B_i}^T
 *           by dividing B_i by diagonal element
 *
-          E( PART_OFFSET+ODD_SIZE ) = E( PART_OFFSET+ODD_SIZE )/
-     $                                D( PART_OFFSET+ODD_SIZE )
+         E( PART_OFFSET+ODD_SIZE ) = E( PART_OFFSET+ODD_SIZE ) /
+     $                               D( PART_OFFSET+ODD_SIZE )
 *
 *
 *
 *         Compute contribution to diagonal block(s) of reduced system.
 *          {C'}_i = {C_i}-{{B'}_i}{{B'}_i}^T
 *
-          D( PART_OFFSET+ODD_SIZE+1 ) = D( PART_OFFSET+ODD_SIZE+1 )-
-     $       D( PART_OFFSET+ODD_SIZE )*( E( PART_OFFSET+ODD_SIZE )*
-     $       ( E( PART_OFFSET+ODD_SIZE ) ) )
+         D( PART_OFFSET+ODD_SIZE+1 ) = D( PART_OFFSET+ODD_SIZE+1 ) -
+     $                                 D( PART_OFFSET+ODD_SIZE )*
+     $                                 ( E( PART_OFFSET+ODD_SIZE )*
+     $                                 ( E( PART_OFFSET+ODD_SIZE ) ) )
 *
-        ENDIF
+      END IF
 *       End of "if ( MYCOL .lt. NP-1 )..." loop
 *
 *
- 1500   CONTINUE
+   20 CONTINUE
 *       If the processor could not locally factor, it jumps here.
 *
-        IF ( MYCOL .NE. 0 ) THEN
+      IF( MYCOL.NE.0 ) THEN
 *
 *         Receive previously transmitted matrix section, which forms
 *         the right-hand-side for the triangular solve that calculates
 *         the "spike" fillin.
 *
 *
-          CALL DTRRV2D( ICTXT, 'U', 'N', 1, 1, AF( 1 ), ODD_SIZE, 0,
-     $                  MYCOL-1 )
+         CALL DTRRV2D( ICTXT, 'U', 'N', 1, 1, AF( 1 ), ODD_SIZE, 0,
+     $                 MYCOL-1 )
 *
-          IF (INFO.EQ.0) THEN
+         IF( INFO.EQ.0 ) THEN
 *
 *         Calculate the "spike" fillin, ${L_i} {{G}_i}^T = {D_i}$ .
 *
-          CALL DPTTRSV( 'N', ODD_SIZE, INT_ONE, D( PART_OFFSET+1 ),
-     $                  E( PART_OFFSET+1 ), AF( 1 ), ODD_SIZE, INFO )
+            CALL DPTTRSV( 'N', ODD_SIZE, INT_ONE, D( PART_OFFSET+1 ),
+     $                    E( PART_OFFSET+1 ), AF( 1 ), ODD_SIZE, INFO )
 *
 *         Divide by D
 *
-        DO 20  I=1, ODD_SIZE
-            AF( I ) = AF( I )/D( PART_OFFSET+I )
-   20     CONTINUE
+            DO 30 I = 1, ODD_SIZE
+               AF( I ) = AF( I ) / D( PART_OFFSET+I )
+   30       CONTINUE
 *
 *
 *         Calculate the update block for previous proc, E_i = G_i{G_i}^T
@@ -728,58 +717,58 @@
 *         Since there is no element-by-element vector multiplication in
 *           the BLAS, this loop must be hardwired in without a BLAS call
 *
-          INT_TEMP = ODD_SIZE*INT_ONE+2+1
-          AF( INT_TEMP ) = 0
+            INT_TEMP = ODD_SIZE*INT_ONE + 2 + 1
+            AF( INT_TEMP ) = 0
 *
-        DO 30  I=1, ODD_SIZE
-            AF( INT_TEMP ) = AF( INT_TEMP )-D( PART_OFFSET+I )*
-     $        ( AF( I )*( AF( I ) ) )
-   30     CONTINUE
+            DO 40 I = 1, ODD_SIZE
+               AF( INT_TEMP ) = AF( INT_TEMP ) -
+     $                          D( PART_OFFSET+I )*( AF( I )*
+     $                          ( AF( I ) ) )
+   40       CONTINUE
 *
 *
 *         Initiate send of E_i to previous processor to overlap
 *           with next computation.
 *
-          CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+3 ),
-     $                  INT_ONE, 0, MYCOL-1 )
+            CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+3 ),
+     $                    INT_ONE, 0, MYCOL-1 )
 *
 *
-          IF ( MYCOL .LT. NP-1 ) THEN
+            IF( MYCOL.LT.NP-1 ) THEN
 *
 *           Calculate off-diagonal block(s) of reduced system.
 *           Note: for ease of use in solution of reduced system, store
 *           L's off-diagonal block in transpose form.
 *           {F_i}^T =  {H_i}{{B'}_i}^T
 *
-            AF( ODD_SIZE+1 ) =
-     $                         - D( PART_OFFSET+ODD_SIZE )
-     $                         * ( E( PART_OFFSET+ODD_SIZE )
-     $                         * AF( ODD_SIZE ) )
+               AF( ODD_SIZE+1 ) = -D( PART_OFFSET+ODD_SIZE )*
+     $                            ( E( PART_OFFSET+ODD_SIZE )*
+     $                            AF( ODD_SIZE ) )
 *
 *
-          ENDIF
+            END IF
 *
-        ENDIF
+         END IF
 *       End of "if ( MYCOL .ne. 0 )..."
 *
-        ENDIF
+      END IF
 *       End of "if (info.eq.0) then"
 *
 *
 *       Check to make sure no processors have found errors
 *
-        CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO,
-     $              -1, 0, 0 )
+      CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO, -1, 0,
+     $              0 )
 *
-        IF( MYCOL.EQ.0 ) THEN
-           CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
-        ELSE
-           CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
-        ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
+      ELSE
+         CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
+      END IF
 *
-        IF ( INFO.NE.0 ) THEN
-           GOTO 1000
-        ENDIF
+      IF( INFO.NE.0 ) THEN
+         GO TO 80
+      END IF
 *       No errors found, continue
 *
 *
@@ -792,42 +781,38 @@
 *
 *     The last processor does not participate in the factorization of
 *       the reduced system, having sent its E_i already.
-      IF( MYCOL .EQ. NPCOL-1 ) THEN
-        GOTO 14
-      ENDIF
+      IF( MYCOL.EQ.NPCOL-1 ) THEN
+         GO TO 70
+      END IF
 *
 *       Initiate send of off-diag block(s) to overlap with next part.
 *       Off-diagonal block needed on neighboring processor to start
 *       algorithm.
 *
-        IF( (MOD( MYCOL+1, 2 ) .EQ. 0) .AND. ( MYCOL .GT. 0 ) ) THEN
+      IF( ( MOD( MYCOL+1, 2 ).EQ.0 ) .AND. ( MYCOL.GT.0 ) ) THEN
 *
-          CALL DGESD2D( ICTXT, INT_ONE, INT_ONE,
-     $                       AF( ODD_SIZE+1 ),
-     $                       INT_ONE, 0, MYCOL-1 )
+         CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+1 ),
+     $                 INT_ONE, 0, MYCOL-1 )
 *
-        ENDIF
+      END IF
 *
 *       Copy last diagonal block into AF storage for subsequent
 *         operations.
 *
-        AF( ODD_SIZE+2 ) =
-     $        DBLE( D( PART_OFFSET+ODD_SIZE+1 ) )
+      AF( ODD_SIZE+2 ) = DBLE( D( PART_OFFSET+ODD_SIZE+1 ) )
 *
 *       Receive cont. to diagonal block that is stored on this proc.
 *
-        IF( MYCOL.LT. NPCOL-1 ) THEN
+      IF( MYCOL.LT.NPCOL-1 ) THEN
 *
-           CALL DGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $               AF( ODD_SIZE+2+1 ),
-     $               INT_ONE, 0,
-     $               MYCOL+1 )
+         CALL DGERV2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+2+1 ),
+     $                 INT_ONE, 0, MYCOL+1 )
 *
 *          Add contribution to diagonal block
 *
-           AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 )+AF( ODD_SIZE+3 )
+         AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 ) + AF( ODD_SIZE+3 )
 *
-        ENDIF
+      END IF
 *
 *
 *       *************************************
@@ -835,91 +820,91 @@
 *
 *       The distance for sending and receiving for each level starts
 *         at 1 for the first level.
-        LEVEL_DIST = 1
+      LEVEL_DIST = 1
 *
 *       Do until this proc is needed to modify other procs' equations
 *
-   12   CONTINUE
-        IF( MOD( (MYCOL+1)/LEVEL_DIST, 2) .NE. 0 ) GOTO 11
+   50 CONTINUE
+      IF( MOD( ( MYCOL+1 ) / LEVEL_DIST, 2 ).NE.0 )
+     $   GO TO 60
 *
 *         Receive and add contribution to diagonal block from the left
 *
-          IF( MYCOL-LEVEL_DIST .GE. 0 ) THEN
-            CALL DGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL-LEVEL_DIST )
+      IF( MYCOL-LEVEL_DIST.GE.0 ) THEN
+         CALL DGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL-LEVEL_DIST )
 *
-            AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 )+WORK( 1 )
+         AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 ) + WORK( 1 )
 *
-          ENDIF
+      END IF
 *
 *         Receive and add contribution to diagonal block from the right
 *
-          IF( MYCOL+LEVEL_DIST .LT. NPCOL-1 ) THEN
-            CALL DGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ),
-     $                        INT_ONE, 0, MYCOL+LEVEL_DIST )
+      IF( MYCOL+LEVEL_DIST.LT.NPCOL-1 ) THEN
+         CALL DGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL+LEVEL_DIST )
 *
-            AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 )+WORK( 1 )
+         AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 ) + WORK( 1 )
 *
-          ENDIF
+      END IF
 *
-          LEVEL_DIST = LEVEL_DIST*2
+      LEVEL_DIST = LEVEL_DIST*2
 *
-        GOTO 12
-   11   CONTINUE
+      GO TO 50
+   60 CONTINUE
 *       [End of GOTO Loop]
 *
 *
 *       *********************************
 *       Calculate and use this proc's blocks to modify other procs'...
-        IF( AF( ODD_SIZE+2 ) .EQ. ZERO ) THEN
-               INFO = NPCOL + MYCOL
-        ENDIF
+      IF( AF( ODD_SIZE+2 ).EQ.ZERO ) THEN
+         INFO = NPCOL + MYCOL
+      END IF
 *
 *       ****************************************************************
 *       Receive offdiagonal block from processor to right.
 *         If this is the first group of processors, the receive comes
 *         from a different processor than otherwise.
 *
-        IF( LEVEL_DIST .EQ. 1 )THEN
-          COMM_PROC = MYCOL + 1
+      IF( LEVEL_DIST.EQ.1 ) THEN
+         COMM_PROC = MYCOL + 1
 *
 *           Move block into place that it will be expected to be for
 *             calcs.
 *
-          AF( ODD_SIZE+3 ) = AF( ODD_SIZE+1 )
+         AF( ODD_SIZE+3 ) = AF( ODD_SIZE+1 )
 *
-        ELSE
-          COMM_PROC = MYCOL + LEVEL_DIST/2
-        ENDIF
+      ELSE
+         COMM_PROC = MYCOL + LEVEL_DIST / 2
+      END IF
 *
-        IF( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-2 )THEN
+      IF( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-2 ) THEN
 *
-          CALL DGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $        AF( ODD_SIZE+1 ),
-     $                       INT_ONE, 0, COMM_PROC )
+         CALL DGERV2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+1 ),
+     $                 INT_ONE, 0, COMM_PROC )
 *
-          IF( INFO .EQ. 0 ) THEN
+         IF( INFO.EQ.0 ) THEN
 *
 *
 *         Modify upper off_diagonal block with diagonal block
 *
 *
-          AF( ODD_SIZE+1 ) = AF( ODD_SIZE+1 )/AF( ODD_SIZE+2 )
+            AF( ODD_SIZE+1 ) = AF( ODD_SIZE+1 ) / AF( ODD_SIZE+2 )
 *
-          ENDIF
+         END IF
 *         End of "if ( info.eq.0 ) then"
 *
 *         Calculate contribution from this block to next diagonal block
 *
-          WORK( 1 ) = -ONE*AF( ODD_SIZE+1 )*AF( ODD_SIZE+2 )
-     $                  *( AF( ODD_SIZE+1 ) )
+         WORK( 1 ) = -ONE*AF( ODD_SIZE+1 )*AF( ODD_SIZE+2 )*
+     $               ( AF( ODD_SIZE+1 ) )
 *
 *         Send contribution to diagonal block's owning processor.
 *
-          CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE,
-     $                     0, MYCOL+LEVEL_DIST )
+         CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL+LEVEL_DIST )
 *
-        ENDIF
+      END IF
 *       End of "if( mycol/level_dist .le. (npcol-1)/level_dist-2 )..."
 *
 *
@@ -927,84 +912,82 @@
 *       Receive off_diagonal block from left and use to finish with this
 *         processor.
 *
-        IF( (MYCOL/LEVEL_DIST .GT. 0 ).AND.
-     $      ( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-1 ) ) THEN
+      IF( ( MYCOL / LEVEL_DIST.GT.0 ) .AND.
+     $    ( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-1 ) ) THEN
 *
-          IF( LEVEL_DIST .GT. 1)THEN
+         IF( LEVEL_DIST.GT.1 ) THEN
 *
-*           Receive offdiagonal block(s) from proc level_dist/2 to the left
+*           Receive offdiagonal block(s) from proc level_dist/2 to the
+*           left
 *
-           CALL DGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $            AF( ODD_SIZE+2+1 ),
-     $            INT_ONE, 0, MYCOL-LEVEL_DIST/2 )
+            CALL DGERV2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+2+1 ),
+     $                    INT_ONE, 0, MYCOL-LEVEL_DIST / 2 )
 *
-          ENDIF
+         END IF
 *
 *
-          IF( INFO.EQ.0 ) THEN
+         IF( INFO.EQ.0 ) THEN
 *
 *         Use diagonal block(s) to modify this offdiagonal block
 *
-          AF( ODD_SIZE+3 ) = ( AF( ODD_SIZE+3 ) )
-     $                         /AF( ODD_SIZE+2 )
+            AF( ODD_SIZE+3 ) = ( AF( ODD_SIZE+3 ) ) / AF( ODD_SIZE+2 )
 *
-          ENDIF
+         END IF
 *         End of "if( info.eq.0 ) then"
 *
 *         Use offdiag block(s) to calculate modification to diag block
 *           of processor to the left
 *
-          WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )*AF( ODD_SIZE+2 )
-     $                  *( AF( ODD_SIZE+3 ) )
+         WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )*AF( ODD_SIZE+2 )*
+     $               ( AF( ODD_SIZE+3 ) )
 *
 *         Send contribution to diagonal block's owning processor.
 *
-          CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE,
-     $                     0, MYCOL-LEVEL_DIST )
+         CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL-LEVEL_DIST )
 *
 *         *******************************************************
 *
-          IF( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-2 ) THEN
+         IF( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-2 ) THEN
 *
 *           Decide which processor offdiagonal block(s) goes to
 *
-            IF( ( MOD( MYCOL/( 2*LEVEL_DIST ),2 )) .EQ.0 ) THEN
-              COMM_PROC = MYCOL + LEVEL_DIST
+            IF( ( MOD( MYCOL / ( 2*LEVEL_DIST ), 2 ) ).EQ.0 ) THEN
+               COMM_PROC = MYCOL + LEVEL_DIST
             ELSE
-              COMM_PROC = MYCOL - LEVEL_DIST
-            ENDIF
+               COMM_PROC = MYCOL - LEVEL_DIST
+            END IF
 *
 *           Use offdiagonal blocks to calculate offdiag
 *             block to send to neighboring processor. Depending
 *             on circumstances, may need to transpose the matrix.
 *
-              WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )
-     $                  * AF( ODD_SIZE+2 )
-     $                  * AF( ODD_SIZE+1 )
+            WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )*AF( ODD_SIZE+2 )*
+     $                  AF( ODD_SIZE+1 )
 *
 *           Send contribution to offdiagonal block's owning processor.
 *
             CALL DGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE,
-     $                         0, COMM_PROC )
+     $                    0, COMM_PROC )
 *
-          ENDIF
+         END IF
 *
-        ENDIF
+      END IF
 *       End of "if( mycol/level_dist.le. (npcol-1)/level_dist -1 )..."
 *
-   14   CONTINUE
+   70 CONTINUE
 *
 *
- 1000 CONTINUE
+   80 CONTINUE
 *
 *
 *     Free BLACS space used to hold standard-form grid.
 *
-      IF( ICTXT_SAVE .NE. ICTXT_NEW ) THEN
+      IF( ICTXT_SAVE.NE.ICTXT_NEW ) THEN
          CALL BLACS_GRIDEXIT( ICTXT_NEW )
-      ENDIF
+      END IF
 *
- 1234 CONTINUE
+   90 CONTINUE
 *
 *     Restore saved input parameters
 *
@@ -1017,14 +1000,14 @@
 *
 *         Make INFO consistent across processors
 *
-          CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO,
-     $              -1, 0, 0 )
+      CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO, -1, 0,
+     $              0 )
 *
-          IF( MYCOL.EQ.0 ) THEN
-             CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
-          ELSE
-             CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
-          ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
+      ELSE
+         CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
+      END IF
 *
 *
       RETURN
