@@ -1,12 +1,10 @@
       SUBROUTINE PDPTTRSV( UPLO, N, NRHS, D, E, JA, DESCA, B, IB, DESCB,
      $                     AF, LAF, WORK, LWORK, INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     April 3, 2000
 *
 *     .. Scalar Arguments ..
       CHARACTER          UPLO
@@ -368,19 +366,18 @@
 *
 *  Code Developer: Andrew J. Cleary, University of Tennessee.
 *    Current address: Lawrence Livermore National Labs.
-*  This version released: May, 1997.
 *
 *  =====================================================================
 *
-*     ..
 *     .. Parameters ..
-      DOUBLE PRECISION   ONE, ZERO
+      DOUBLE PRECISION   ONE
       PARAMETER          ( ONE = 1.0D+0 )
+      DOUBLE PRECISION   ZERO
       PARAMETER          ( ZERO = 0.0D+0 )
       INTEGER            INT_ONE
       PARAMETER          ( INT_ONE = 1 )
       INTEGER            DESCMULT, BIGNUM
-      PARAMETER          (DESCMULT = 100, BIGNUM = DESCMULT * DESCMULT)
+      PARAMETER          ( DESCMULT = 100, BIGNUM = DESCMULT*DESCMULT )
       INTEGER            BLOCK_CYCLIC_2D, CSRC_, CTXT_, DLEN_, DTYPE_,
      $                   LLD_, MB_, M_, NB_, N_, RSRC_
       PARAMETER          ( BLOCK_CYCLIC_2D = 1, DLEN_ = 9, DTYPE_ = 1,
@@ -400,10 +397,9 @@
      $                   PARAM_CHECK( 15, 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GET, BLACS_GRIDEXIT, BLACS_GRIDINFO,
-     $                   DESC_CONVERT, DGEMM, DGERV2D, DGESD2D, DLACPY,
-     $                   DMATADD, DTBTRS, DTRMM, DTRTRS, GLOBCHK,
-     $                   PXERBLA, RESHAPE
+      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DAXPY,
+     $                   DESC_CONVERT, DGEMM, DGERV2D, DGESD2D, DMATADD,
+     $                   DPTTRSV, DTRTRS, GLOBCHK, PXERBLA, RESHAPE
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -411,7 +407,7 @@
       EXTERNAL           LSAME, NUMROC
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ICHAR, MIN, MOD
+      INTRINSIC          ICHAR, MOD
 *     ..
 *     .. Executable Statements ..
 *
@@ -426,45 +422,45 @@
       DESCB_PX1( 1 ) = 502
 *
       TEMP = DESCA( DTYPE_ )
-      IF( TEMP .EQ. 502 ) THEN
+      IF( TEMP.EQ.502 ) THEN
 *        Temporarily set the descriptor type to 1xP type
          DESCA( DTYPE_ ) = 501
-      ENDIF
+      END IF
 *
       CALL DESC_CONVERT( DESCA, DESCA_1XP, RETURN_CODE )
 *
       DESCA( DTYPE_ ) = TEMP
 *
-      IF( RETURN_CODE .NE. 0) THEN
-         INFO = -( 7*100 + 2 )
-      ENDIF
+      IF( RETURN_CODE.NE.0 ) THEN
+         INFO = -( 7*100+2 )
+      END IF
 *
       CALL DESC_CONVERT( DESCB, DESCB_PX1, RETURN_CODE )
 *
-      IF( RETURN_CODE .NE. 0) THEN
-         INFO = -( 10*100 + 2 )
-      ENDIF
+      IF( RETURN_CODE.NE.0 ) THEN
+         INFO = -( 10*100+2 )
+      END IF
 *
 *     Consistency checks for DESCA and DESCB.
 *
 *     Context must be the same
-      IF( DESCA_1XP( 2 ) .NE. DESCB_PX1( 2 ) ) THEN
-         INFO = -( 10*100 + 2 )
-      ENDIF
+      IF( DESCA_1XP( 2 ).NE.DESCB_PX1( 2 ) ) THEN
+         INFO = -( 10*100+2 )
+      END IF
 *
 *        These are alignment restrictions that may or may not be removed
 *        in future releases. -Andy Cleary, April 14, 1996.
 *
 *     Block sizes must be the same
-      IF( DESCA_1XP( 4 ) .NE. DESCB_PX1( 4 ) ) THEN
-         INFO = -( 10*100 + 4 )
-      ENDIF
+      IF( DESCA_1XP( 4 ).NE.DESCB_PX1( 4 ) ) THEN
+         INFO = -( 10*100+4 )
+      END IF
 *
 *     Source processor must be the same
 *
-      IF( DESCA_1XP( 5 ) .NE. DESCB_PX1( 5 ) ) THEN
-         INFO = -( 10*100 + 5 )
-      ENDIF
+      IF( DESCA_1XP( 5 ).NE.DESCB_PX1( 5 ) ) THEN
+         INFO = -( 10*100+5 )
+      END IF
 *
 *     Get values out of descriptor for use in code.
 *
@@ -480,107 +476,103 @@
 *
 *
       CALL BLACS_GRIDINFO( ICTXT, NPROW, NPCOL, MYROW, MYCOL )
-      NP = NPROW * NPCOL
+      NP = NPROW*NPCOL
 *
 *
 *
       IF( LSAME( UPLO, 'U' ) ) THEN
          IDUM1 = ICHAR( 'U' )
-      ELSE IF ( LSAME( UPLO, 'L' ) ) THEN
+      ELSE IF( LSAME( UPLO, 'L' ) ) THEN
          IDUM1 = ICHAR( 'L' )
       ELSE
          INFO = -1
       END IF
 *
-      IF( LWORK .LT. -1) THEN
+      IF( LWORK.LT.-1 ) THEN
          INFO = -14
-      ELSE IF ( LWORK .EQ. -1 ) THEN
+      ELSE IF( LWORK.EQ.-1 ) THEN
          IDUM3 = -1
       ELSE
          IDUM3 = 1
-      ENDIF
+      END IF
 *
-      IF( N .LT. 0 ) THEN
+      IF( N.LT.0 ) THEN
          INFO = -2
-      ENDIF
+      END IF
 *
-      IF( N+JA-1 .GT. STORE_N_A ) THEN
-         INFO = -( 7*100 + 6 )
-      ENDIF
+      IF( N+JA-1.GT.STORE_N_A ) THEN
+         INFO = -( 7*100+6 )
+      END IF
 *
-      IF( N+IB-1 .GT. STORE_M_B ) THEN
-         INFO = -( 10*100 + 3 )
-      ENDIF
+      IF( N+IB-1.GT.STORE_M_B ) THEN
+         INFO = -( 10*100+3 )
+      END IF
 *
-      IF( LLDB .LT. NB ) THEN
-         INFO = -( 10*100 + 6 )
-      ENDIF
+      IF( LLDB.LT.NB ) THEN
+         INFO = -( 10*100+6 )
+      END IF
 *
-      IF( NRHS .LT. 0 ) THEN
+      IF( NRHS.LT.0 ) THEN
          INFO = -3
-      ENDIF
+      END IF
 *
 *     Current alignment restriction
 *
-      IF( JA .NE. IB) THEN
+      IF( JA.NE.IB ) THEN
          INFO = -6
-      ENDIF
+      END IF
 *
 *     Argument checking that is specific to Divide & Conquer routine
 *
-      IF( NPROW .NE. 1 ) THEN
+      IF( NPROW.NE.1 ) THEN
          INFO = -( 7*100+2 )
-      ENDIF
+      END IF
 *
-      IF( N .GT. NP*NB-MOD( JA-1, NB )) THEN
+      IF( N.GT.NP*NB-MOD( JA-1, NB ) ) THEN
          INFO = -( 2 )
          CALL PXERBLA( ICTXT,
-     $      'PDPTTRSV, D&C alg.: only 1 block per proc',
-     $      -INFO )
+     $                 'PDPTTRSV, D&C alg.: only 1 block per proc',
+     $                 -INFO )
          RETURN
-      ENDIF
+      END IF
 *
-      IF((JA+N-1.GT.NB) .AND. ( NB.LT.2*INT_ONE )) THEN
+      IF( ( JA+N-1.GT.NB ) .AND. ( NB.LT.2*INT_ONE ) ) THEN
          INFO = -( 7*100+4 )
-         CALL PXERBLA( ICTXT,
-     $      'PDPTTRSV, D&C alg.: NB too small',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PDPTTRSV, D&C alg.: NB too small',
+     $                 -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *
-      WORK_SIZE_MIN =
-     $           INT_ONE*NRHS
+      WORK_SIZE_MIN = INT_ONE*NRHS
 *
       WORK( 1 ) = WORK_SIZE_MIN
 *
-      IF( LWORK .LT. WORK_SIZE_MIN ) THEN
-         IF( LWORK .NE. -1 ) THEN
-         INFO = -14
-         CALL PXERBLA( ICTXT,
-     $      'PDPTTRSV: worksize error',
-     $      -INFO )
-         ENDIF
+      IF( LWORK.LT.WORK_SIZE_MIN ) THEN
+         IF( LWORK.NE.-1 ) THEN
+            INFO = -14
+            CALL PXERBLA( ICTXT, 'PDPTTRSV: worksize error', -INFO )
+         END IF
          RETURN
-      ENDIF
+      END IF
 *
 *     Pack params and positions into arrays for global consistency check
 *
-      PARAM_CHECK( 15, 1 ) = DESCB(5)
-      PARAM_CHECK( 14, 1 ) = DESCB(4)
-      PARAM_CHECK( 13, 1 ) = DESCB(3)
-      PARAM_CHECK( 12, 1 ) = DESCB(2)
-      PARAM_CHECK( 11, 1 ) = DESCB(1)
+      PARAM_CHECK( 15, 1 ) = DESCB( 5 )
+      PARAM_CHECK( 14, 1 ) = DESCB( 4 )
+      PARAM_CHECK( 13, 1 ) = DESCB( 3 )
+      PARAM_CHECK( 12, 1 ) = DESCB( 2 )
+      PARAM_CHECK( 11, 1 ) = DESCB( 1 )
       PARAM_CHECK( 10, 1 ) = IB
-      PARAM_CHECK(  9, 1 ) = DESCA(5)
-      PARAM_CHECK(  8, 1 ) = DESCA(4)
-      PARAM_CHECK(  7, 1 ) = DESCA(3)
-      PARAM_CHECK(  6, 1 ) = DESCA(1)
-      PARAM_CHECK(  5, 1 ) = JA
-      PARAM_CHECK(  4, 1 ) = NRHS
-      PARAM_CHECK(  3, 1 ) = N
-      PARAM_CHECK(  2, 1 ) = IDUM3
-      PARAM_CHECK(  1, 1 ) = IDUM1
+      PARAM_CHECK( 9, 1 ) = DESCA( 5 )
+      PARAM_CHECK( 8, 1 ) = DESCA( 4 )
+      PARAM_CHECK( 7, 1 ) = DESCA( 3 )
+      PARAM_CHECK( 6, 1 ) = DESCA( 1 )
+      PARAM_CHECK( 5, 1 ) = JA
+      PARAM_CHECK( 4, 1 ) = NRHS
+      PARAM_CHECK( 3, 1 ) = N
+      PARAM_CHECK( 2, 1 ) = IDUM3
+      PARAM_CHECK( 1, 1 ) = IDUM1
 *
       PARAM_CHECK( 15, 2 ) = 1005
       PARAM_CHECK( 14, 2 ) = 1004
@@ -588,15 +580,15 @@
       PARAM_CHECK( 12, 2 ) = 1002
       PARAM_CHECK( 11, 2 ) = 1001
       PARAM_CHECK( 10, 2 ) = 9
-      PARAM_CHECK(  9, 2 ) = 705
-      PARAM_CHECK(  8, 2 ) = 704
-      PARAM_CHECK(  7, 2 ) = 703
-      PARAM_CHECK(  6, 2 ) = 701
-      PARAM_CHECK(  5, 2 ) = 6
-      PARAM_CHECK(  4, 2 ) = 3
-      PARAM_CHECK(  3, 2 ) = 2
-      PARAM_CHECK(  2, 2 ) = 14
-      PARAM_CHECK(  1, 2 ) = 1
+      PARAM_CHECK( 9, 2 ) = 705
+      PARAM_CHECK( 8, 2 ) = 704
+      PARAM_CHECK( 7, 2 ) = 703
+      PARAM_CHECK( 6, 2 ) = 701
+      PARAM_CHECK( 5, 2 ) = 6
+      PARAM_CHECK( 4, 2 ) = 3
+      PARAM_CHECK( 3, 2 ) = 2
+      PARAM_CHECK( 2, 2 ) = 14
+      PARAM_CHECK( 1, 2 ) = 1
 *
 *     Want to find errors with MIN( ), so if no error, set it to a big
 *     number. If there already is an error, multiply by the the
@@ -607,20 +599,20 @@
       ELSE IF( INFO.LT.-DESCMULT ) THEN
          INFO = -INFO
       ELSE
-         INFO = -INFO * DESCMULT
+         INFO = -INFO*DESCMULT
       END IF
 *
 *     Check consistency across processors
 *
-      CALL GLOBCHK( ICTXT, 15, PARAM_CHECK, 15,
-     $              PARAM_CHECK( 1, 3 ), INFO )
+      CALL GLOBCHK( ICTXT, 15, PARAM_CHECK, 15, PARAM_CHECK( 1, 3 ),
+     $              INFO )
 *
 *     Prepare output: set info = 0 if no error, and divide by DESCMULT
 *     if error is not in a descriptor entry.
 *
       IF( INFO.EQ.BIGNUM ) THEN
          INFO = 0
-      ELSE IF( MOD( INFO, DESCMULT ) .EQ. 0 ) THEN
+      ELSE IF( MOD( INFO, DESCMULT ).EQ.0 ) THEN
          INFO = -INFO / DESCMULT
       ELSE
          INFO = -INFO
@@ -643,15 +635,15 @@
 *     Adjust addressing into matrix space to properly get into
 *        the beginning part of the relevant data
 *
-      PART_OFFSET = NB*( (JA-1)/(NPCOL*NB) )
+      PART_OFFSET = NB*( ( JA-1 ) / ( NPCOL*NB ) )
 *
-      IF ( (MYCOL-CSRC) .LT. (JA-PART_OFFSET-1)/NB ) THEN
+      IF( ( MYCOL-CSRC ).LT.( JA-PART_OFFSET-1 ) / NB ) THEN
          PART_OFFSET = PART_OFFSET + NB
-      ENDIF
+      END IF
 *
-      IF ( MYCOL .LT. CSRC ) THEN
+      IF( MYCOL.LT.CSRC ) THEN
          PART_OFFSET = PART_OFFSET - NB
-      ENDIF
+      END IF
 *
 *     Form a new BLACS grid (the "standard form" grid) with only procs
 *        holding part of the matrix, of size 1xNP where NP is adjusted,
@@ -659,7 +651,7 @@
 *
 *     First processor to hold part of the matrix:
 *
-      FIRST_PROC = MOD( ( JA-1 )/NB+CSRC, NPCOL )
+      FIRST_PROC = MOD( ( JA-1 ) / NB+CSRC, NPCOL )
 *
 *     Calculate new JA one while dropping off unused processors.
 *
@@ -668,12 +660,12 @@
 *     Save and compute new value of NP
 *
       NP_SAVE = NP
-      NP = ( JA_NEW+N-2 )/NB + 1
+      NP = ( JA_NEW+N-2 ) / NB + 1
 *
 *     Call utility routine that forms "standard-form" grid
 *
-      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE,
-     $              FIRST_PROC, INT_ONE, NP )
+      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE, FIRST_PROC,
+     $              INT_ONE, NP )
 *
 *     Use new context from standard grid as context.
 *
@@ -688,9 +680,9 @@
 *
 *     Drop out processors that do not have part of the matrix.
 *
-      IF( MYROW .LT. 0 ) THEN
-         GOTO 1234
-      ENDIF
+      IF( MYROW.LT.0 ) THEN
+         GO TO 100
+      END IF
 *
 *     ********************************
 *     Values reused throughout routine
@@ -705,23 +697,23 @@
 *
 *     Offset in columns to beginning of main partition in each proc
 *
-      IF ( MYCOL .EQ. 0 ) THEN
-        PART_OFFSET = PART_OFFSET+MOD( JA_NEW-1, PART_SIZE )
-        MY_NUM_COLS = MY_NUM_COLS - MOD(JA_NEW-1, PART_SIZE )
-      ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         PART_OFFSET = PART_OFFSET + MOD( JA_NEW-1, PART_SIZE )
+         MY_NUM_COLS = MY_NUM_COLS - MOD( JA_NEW-1, PART_SIZE )
+      END IF
 *
 *     Size of main (or odd) partition in each processor
 *
       ODD_SIZE = MY_NUM_COLS
-      IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
          ODD_SIZE = ODD_SIZE - INT_ONE
-      ENDIF
+      END IF
 *
 *
 *
 *     Begin main code
 *
-      IF ( LSAME( UPLO, 'L' ) ) THEN
+      IF( LSAME( UPLO, 'L' ) ) THEN
 *
 *
 *        Frontsolve
@@ -733,30 +725,30 @@
 *
 *       Use main partition in each processor to solve locally
 *
-        CALL DPTTRSV( 'N', ODD_SIZE, NRHS, D( PART_OFFSET+1 ),
-     $                E( PART_OFFSET+1 ), B( PART_OFFSET+1 ), LLDB,
-     $                INFO )
+         CALL DPTTRSV( 'N', ODD_SIZE, NRHS, D( PART_OFFSET+1 ),
+     $                 E( PART_OFFSET+1 ), B( PART_OFFSET+1 ), LLDB,
+     $                 INFO )
 *
 *
-        IF ( MYCOL .LT. NP-1 ) THEN
+         IF( MYCOL.LT.NP-1 ) THEN
 *         Use factorization of odd-even connection block to modify
 *           locally stored portion of right hand side(s)
 *
             CALL DAXPY( NRHS, -E( PART_OFFSET+ODD_SIZE ),
-     $            B( PART_OFFSET+ODD_SIZE ), LLDB,
-     $            B( PART_OFFSET+ODD_SIZE+1 ), LLDB )
+     $                  B( PART_OFFSET+ODD_SIZE ), LLDB,
+     $                  B( PART_OFFSET+ODD_SIZE+1 ), LLDB )
 *
-        ENDIF
+         END IF
 *
 *
-        IF ( MYCOL .NE. 0 ) THEN
+         IF( MYCOL.NE.0 ) THEN
 *         Use the "spike" fillin to calculate contribution to previous
 *           processor's righthand-side.
 *
             CALL DGEMM( 'T', 'N', 1, NRHS, ODD_SIZE, -ONE, AF( 1 ),
      $                  ODD_SIZE, B( PART_OFFSET+1 ), LLDB, ZERO,
      $                  WORK( 1+INT_ONE-1 ), INT_ONE )
-        ENDIF
+         END IF
 *
 *
 ************************************************
@@ -766,36 +758,33 @@
 *
 *       Send modifications to prior processor's right hand sides
 *
-        IF( MYCOL .GT. 0) THEN
+         IF( MYCOL.GT.0 ) THEN
 *
-          CALL DGESD2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ), INT_ONE,
-     $                     0, MYCOL - 1 )
+            CALL DGESD2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL-1 )
 *
-        ENDIF
+         END IF
 *
 *       Receive modifications to processor's right hand sides
 *
-        IF( MYCOL .LT. NPCOL-1) THEN
+         IF( MYCOL.LT.NPCOL-1 ) THEN
 *
-          CALL DGERV2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ), INT_ONE,
-     $                     0, MYCOL + 1 )
+            CALL DGERV2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL+1 )
 *
 *         Combine contribution to locally stored right hand sides
 *
-          CALL DMATADD( INT_ONE, NRHS, ONE,
-     $                WORK( 1 ), INT_ONE, ONE,
-     $                B( PART_OFFSET+ODD_SIZE + 1 ), LLDB )
+            CALL DMATADD( INT_ONE, NRHS, ONE, WORK( 1 ), INT_ONE, ONE,
+     $                    B( PART_OFFSET+ODD_SIZE+1 ), LLDB )
 *
-        ENDIF
+         END IF
 *
 *
 *       The last processor does not participate in the solution of the
 *       reduced system, having sent its contribution already.
-        IF( MYCOL .EQ. NPCOL-1 ) THEN
-          GOTO 14
-        ENDIF
+         IF( MYCOL.EQ.NPCOL-1 ) THEN
+            GO TO 30
+         END IF
 *
 *
 *       *************************************
@@ -803,45 +792,42 @@
 *
 *       The distance for sending and receiving for each level starts
 *         at 1 for the first level.
-        LEVEL_DIST = 1
+         LEVEL_DIST = 1
 *
 *       Do until this proc is needed to modify other procs' equations
 *
-   12   CONTINUE
-        IF( MOD( (MYCOL+1)/LEVEL_DIST, 2) .NE. 0 ) GOTO 11
+   10    CONTINUE
+         IF( MOD( ( MYCOL+1 ) / LEVEL_DIST, 2 ).NE.0 )
+     $      GO TO 20
 *
 *         Receive and add contribution to righthand sides from left
 *
-          IF( MYCOL-LEVEL_DIST .GE. 0 ) THEN
+         IF( MYCOL-LEVEL_DIST.GE.0 ) THEN
 *
-            CALL DGERV2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL-LEVEL_DIST )
+            CALL DGERV2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL-LEVEL_DIST )
 *
-            CALL DMATADD( INT_ONE, NRHS, ONE,
-     $                WORK( 1 ), INT_ONE, ONE,
-     $                B( PART_OFFSET+ODD_SIZE + 1 ), LLDB )
+            CALL DMATADD( INT_ONE, NRHS, ONE, WORK( 1 ), INT_ONE, ONE,
+     $                    B( PART_OFFSET+ODD_SIZE+1 ), LLDB )
 *
-          ENDIF
+         END IF
 *
 *         Receive and add contribution to righthand sides from right
 *
-          IF( MYCOL+LEVEL_DIST .LT. NPCOL-1 ) THEN
+         IF( MYCOL+LEVEL_DIST.LT.NPCOL-1 ) THEN
 *
-            CALL DGERV2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL+LEVEL_DIST )
+            CALL DGERV2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL+LEVEL_DIST )
 *
-            CALL DMATADD( INT_ONE, NRHS, ONE,
-     $                WORK( 1 ), INT_ONE, ONE,
-     $                B( PART_OFFSET+ODD_SIZE + 1 ), LLDB )
+            CALL DMATADD( INT_ONE, NRHS, ONE, WORK( 1 ), INT_ONE, ONE,
+     $                    B( PART_OFFSET+ODD_SIZE+1 ), LLDB )
 *
-          ENDIF
+         END IF
 *
-          LEVEL_DIST = LEVEL_DIST*2
+         LEVEL_DIST = LEVEL_DIST*2
 *
-        GOTO 12
-   11   CONTINUE
+         GO TO 10
+   20    CONTINUE
 *       [End of GOTO Loop]
 *
 *
@@ -851,63 +837,55 @@
 *
 *       Solve with diagonal block
 *
-        CALL DTRTRS( 'L', 'N', 'U', INT_ONE, NRHS, AF( ODD_SIZE+2 ),
-     $               INT_ONE, B( PART_OFFSET+ODD_SIZE+1 ), LLDB, INFO )
+         CALL DTRTRS( 'L', 'N', 'U', INT_ONE, NRHS, AF( ODD_SIZE+2 ),
+     $                INT_ONE, B( PART_OFFSET+ODD_SIZE+1 ), LLDB, INFO )
 *
-        IF( INFO.NE.0 ) THEN
-          GO TO 1000
-        ENDIF
+         IF( INFO.NE.0 ) THEN
+            GO TO 90
+         END IF
 *
 *
 *
 *       *********
-        IF( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-2 )THEN
+         IF( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-2 ) THEN
 *
 *         Calculate contribution from this block to next diagonal block
 *
-          CALL DGEMM( 'T', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
-     $                     AF( (ODD_SIZE)*1+1 ),
-     $                     INT_ONE,
-     $                     B( PART_OFFSET+ODD_SIZE+1 ),
-     $                     LLDB, ZERO,
-     $                     WORK( 1 ),
-     $                     INT_ONE )
+            CALL DGEMM( 'T', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
+     $                  AF( ( ODD_SIZE )*1+1 ), INT_ONE,
+     $                  B( PART_OFFSET+ODD_SIZE+1 ), LLDB, ZERO,
+     $                  WORK( 1 ), INT_ONE )
 *
 *         Send contribution to diagonal block's owning processor.
 *
-          CALL DGESD2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL+LEVEL_DIST )
+            CALL DGESD2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL+LEVEL_DIST )
 *
-        ENDIF
+         END IF
 *       End of "if( mycol/level_dist .le. (npcol-1)/level_dist-2 )..."
 *
 *       ************
-        IF( (MYCOL/LEVEL_DIST .GT. 0 ).AND.
-     $      ( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-1 ) ) THEN
+         IF( ( MYCOL / LEVEL_DIST.GT.0 ) .AND.
+     $       ( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-1 ) ) THEN
 *
 *
 *         Use offdiagonal block to calculate modification to diag block
 *           of processor to the left
 *
-          CALL DGEMM( 'N', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
-     $                     AF( ODD_SIZE*1+2+1 ),
-     $                     INT_ONE,
-     $                     B( PART_OFFSET+ODD_SIZE+1 ),
-     $                     LLDB, ZERO,
-     $                     WORK( 1 ),
-     $                     INT_ONE )
+            CALL DGEMM( 'N', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
+     $                  AF( ODD_SIZE*1+2+1 ), INT_ONE,
+     $                  B( PART_OFFSET+ODD_SIZE+1 ), LLDB, ZERO,
+     $                  WORK( 1 ), INT_ONE )
 *
 *         Send contribution to diagonal block's owning processor.
 *
-          CALL DGESD2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL-LEVEL_DIST )
+            CALL DGESD2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL-LEVEL_DIST )
 *
-        ENDIF
+         END IF
 *       End of "if( mycol/level_dist.le. (npcol-1)/level_dist -1 )..."
 *
-   14  CONTINUE
+   30    CONTINUE
 *
       ELSE
 *
@@ -921,111 +899,105 @@
 *
 *       The last processor does not participate in the solution of the
 *       reduced system and just waits to receive its solution.
-        IF( MYCOL .EQ. NPCOL-1 ) THEN
-          GOTO 24
-        ENDIF
+         IF( MYCOL.EQ.NPCOL-1 ) THEN
+            GO TO 80
+         END IF
 *
 *       Determine number of steps in tree loop
 *
-        LEVEL_DIST = 1
-   27   CONTINUE
-        IF( MOD( (MYCOL+1)/LEVEL_DIST, 2) .NE. 0 ) GOTO 26
+         LEVEL_DIST = 1
+   40    CONTINUE
+         IF( MOD( ( MYCOL+1 ) / LEVEL_DIST, 2 ).NE.0 )
+     $      GO TO 50
 *
-          LEVEL_DIST = LEVEL_DIST*2
+         LEVEL_DIST = LEVEL_DIST*2
 *
-        GOTO 27
-   26   CONTINUE
+         GO TO 40
+   50    CONTINUE
 *
 *
-        IF( (MYCOL/LEVEL_DIST .GT. 0 ).AND.
-     $      ( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-1 ) ) THEN
+         IF( ( MYCOL / LEVEL_DIST.GT.0 ) .AND.
+     $       ( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-1 ) ) THEN
 *
 *         Receive solution from processor to left
 *
-          CALL DGERV2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL-LEVEL_DIST )
+            CALL DGERV2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL-LEVEL_DIST )
 *
 *
 *         Use offdiagonal block to calculate modification to RHS stored
 *           on this processor
 *
-          CALL DGEMM( 'T', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
-     $                     AF( ODD_SIZE*1+2+1 ),
-     $                     INT_ONE,
-     $                     WORK( 1 ),
-     $                     INT_ONE, ONE,
-     $                     B( PART_OFFSET+ODD_SIZE+1 ),
-     $                     LLDB )
-        ENDIF
+            CALL DGEMM( 'T', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
+     $                  AF( ODD_SIZE*1+2+1 ), INT_ONE, WORK( 1 ),
+     $                  INT_ONE, ONE, B( PART_OFFSET+ODD_SIZE+1 ),
+     $                  LLDB )
+         END IF
 *       End of "if( mycol/level_dist.le. (npcol-1)/level_dist -1 )..."
 *
 *
-        IF( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-2 )THEN
+         IF( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-2 ) THEN
 *
 *         Receive solution from processor to right
 *
-          CALL DGERV2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL+LEVEL_DIST )
+            CALL DGERV2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL+LEVEL_DIST )
 *
 *         Calculate contribution from this block to next diagonal block
 *
-          CALL DGEMM( 'N', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
-     $                     AF( (ODD_SIZE)*1+1 ),
-     $                     INT_ONE,
-     $                     WORK( 1 ),
-     $                     INT_ONE, ONE,
-     $                     B( PART_OFFSET+ODD_SIZE+1 ),
-     $                     LLDB )
+            CALL DGEMM( 'N', 'N', INT_ONE, NRHS, INT_ONE, -ONE,
+     $                  AF( ( ODD_SIZE )*1+1 ), INT_ONE, WORK( 1 ),
+     $                  INT_ONE, ONE, B( PART_OFFSET+ODD_SIZE+1 ),
+     $                  LLDB )
 *
-        ENDIF
+         END IF
 *       End of "if( mycol/level_dist .le. (npcol-1)/level_dist-2 )..."
 *
 *
 *       Solve with diagonal block
 *
-        CALL DTRTRS( 'L', 'T', 'U', INT_ONE, NRHS, AF( ODD_SIZE+2 ),
-     $               INT_ONE, B( PART_OFFSET+ODD_SIZE+1 ), LLDB, INFO )
+         CALL DTRTRS( 'L', 'T', 'U', INT_ONE, NRHS, AF( ODD_SIZE+2 ),
+     $                INT_ONE, B( PART_OFFSET+ODD_SIZE+1 ), LLDB, INFO )
 *
-        IF( INFO.NE.0 ) THEN
-          GO TO 1000
-        ENDIF
+         IF( INFO.NE.0 ) THEN
+            GO TO 90
+         END IF
 *
 *
 *
 ***Modification Loop *******
 *
-   22   CONTINUE
-        IF( LEVEL_DIST .EQ. 1 ) GOTO 21
+   60    CONTINUE
+         IF( LEVEL_DIST.EQ.1 )
+     $      GO TO 70
 *
-          LEVEL_DIST = LEVEL_DIST/2
+         LEVEL_DIST = LEVEL_DIST / 2
 *
 *         Send solution to the right
 *
-          IF( MYCOL+LEVEL_DIST .LT. NPCOL-1 ) THEN
+         IF( MYCOL+LEVEL_DIST.LT.NPCOL-1 ) THEN
 *
-          CALL DGESD2D( ICTXT, INT_ONE, NRHS,
-     $                     B( PART_OFFSET+ODD_SIZE+1 ),
-     $                     LLDB, 0, MYCOL+LEVEL_DIST )
+            CALL DGESD2D( ICTXT, INT_ONE, NRHS,
+     $                    B( PART_OFFSET+ODD_SIZE+1 ), LLDB, 0,
+     $                    MYCOL+LEVEL_DIST )
 *
-          ENDIF
+         END IF
 *
 *         Send solution to left
 *
-          IF( MYCOL-LEVEL_DIST .GE. 0 ) THEN
+         IF( MYCOL-LEVEL_DIST.GE.0 ) THEN
 *
-          CALL DGESD2D( ICTXT, INT_ONE, NRHS,
-     $                     B( PART_OFFSET+ODD_SIZE+1 ),
-     $                     LLDB, 0, MYCOL-LEVEL_DIST )
+            CALL DGESD2D( ICTXT, INT_ONE, NRHS,
+     $                    B( PART_OFFSET+ODD_SIZE+1 ), LLDB, 0,
+     $                    MYCOL-LEVEL_DIST )
 *
-          ENDIF
+         END IF
 *
-        GOTO 22
-   21   CONTINUE
+         GO TO 60
+   70    CONTINUE
 *       [End of GOTO Loop]
 *
-   24   CONTINUE
+   80    CONTINUE
 *          [Processor npcol - 1 jumped to here to await next stage]
 *
 *******************************
@@ -1035,23 +1007,22 @@
 *
 *       Send elements of solution to next proc
 *
-        IF( MYCOL .LT. NPCOL-1) THEN
+         IF( MYCOL.LT.NPCOL-1 ) THEN
 *
-          CALL DGESD2D( ICTXT, INT_ONE, NRHS,
-     $                     B( PART_OFFSET+ODD_SIZE+1 ), LLDB,
-     $                     0, MYCOL +1 )
+            CALL DGESD2D( ICTXT, INT_ONE, NRHS,
+     $                    B( PART_OFFSET+ODD_SIZE+1 ), LLDB, 0,
+     $                    MYCOL+1 )
 *
-        ENDIF
+         END IF
 *
 *       Receive modifications to processor's right hand sides
 *
-        IF( MYCOL .GT. 0) THEN
+         IF( MYCOL.GT.0 ) THEN
 *
-          CALL DGERV2D( ICTXT, INT_ONE, NRHS,
-     $                     WORK( 1 ), INT_ONE,
-     $                     0, MYCOL - 1 )
+            CALL DGERV2D( ICTXT, INT_ONE, NRHS, WORK( 1 ), INT_ONE, 0,
+     $                    MYCOL-1 )
 *
-        ENDIF
+         END IF
 *
 *
 *
@@ -1059,46 +1030,46 @@
 *       Local computation phase
 **********************************************
 *
-        IF ( MYCOL .NE. 0 ) THEN
+         IF( MYCOL.NE.0 ) THEN
 *         Use the "spike" fillin to calculate contribution from previous
 *           processor's solution.
 *
-          CALL DGEMM( 'N', 'N', ODD_SIZE, NRHS, 1, -ONE, AF( 1 ),
-     $                ODD_SIZE, WORK( 1+INT_ONE-1 ), INT_ONE, ONE,
-     $                B( PART_OFFSET+1 ), LLDB )
+            CALL DGEMM( 'N', 'N', ODD_SIZE, NRHS, 1, -ONE, AF( 1 ),
+     $                  ODD_SIZE, WORK( 1+INT_ONE-1 ), INT_ONE, ONE,
+     $                  B( PART_OFFSET+1 ), LLDB )
 *
-        ENDIF
+         END IF
 *
 *
-        IF ( MYCOL .LT. NP-1 ) THEN
+         IF( MYCOL.LT.NP-1 ) THEN
 *         Use factorization of odd-even connection block to modify
 *           locally stored portion of right hand side(s)
 *
             CALL DAXPY( NRHS, -( E( PART_OFFSET+ODD_SIZE ) ),
-     $                 B( PART_OFFSET+ODD_SIZE+1 ), LLDB,
-     $                 B( PART_OFFSET+ODD_SIZE ), LLDB )
+     $                  B( PART_OFFSET+ODD_SIZE+1 ), LLDB,
+     $                  B( PART_OFFSET+ODD_SIZE ), LLDB )
 *
-        ENDIF
+         END IF
 *
 *       Use main partition in each processor to solve locally
 *
-        CALL DPTTRSV( 'T', ODD_SIZE, NRHS, D( PART_OFFSET+1 ),
-     $                E( PART_OFFSET+1 ), B( PART_OFFSET+1 ), LLDB,
-     $                INFO )
+         CALL DPTTRSV( 'T', ODD_SIZE, NRHS, D( PART_OFFSET+1 ),
+     $                 E( PART_OFFSET+1 ), B( PART_OFFSET+1 ), LLDB,
+     $                 INFO )
 *
 *
-      ENDIF
+      END IF
 *     End of "IF( LSAME( UPLO, 'L' ) )"...
- 1000 CONTINUE
+   90 CONTINUE
 *
 *
 *     Free BLACS space used to hold standard-form grid.
 *
-      IF( ICTXT_SAVE .NE. ICTXT_NEW ) THEN
+      IF( ICTXT_SAVE.NE.ICTXT_NEW ) THEN
          CALL BLACS_GRIDEXIT( ICTXT_NEW )
-      ENDIF
+      END IF
 *
- 1234 CONTINUE
+  100 CONTINUE
 *
 *     Restore saved input parameters
 *
