@@ -1,12 +1,10 @@
       SUBROUTINE PSDTTRF( N, DL, D, DU, JA, DESCA, AF, LAF, WORK, LWORK,
      $                    INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.6) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     November 15, 1997
+*     April 3, 2000
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, JA, LAF, LWORK, N
@@ -350,19 +348,18 @@
 *
 *  Code Developer: Andrew J. Cleary, University of Tennessee.
 *    Current address: Lawrence Livermore National Labs.
-*  This version released: May, 1997.
 *
 *  =====================================================================
 *
-*     ..
 *     .. Parameters ..
-      REAL               ONE, ZERO
+      REAL               ONE
       PARAMETER          ( ONE = 1.0E+0 )
+      REAL               ZERO
       PARAMETER          ( ZERO = 0.0E+0 )
       INTEGER            INT_ONE
       PARAMETER          ( INT_ONE = 1 )
       INTEGER            DESCMULT, BIGNUM
-      PARAMETER          (DESCMULT = 100, BIGNUM = DESCMULT * DESCMULT)
+      PARAMETER          ( DESCMULT = 100, BIGNUM = DESCMULT*DESCMULT )
       INTEGER            BLOCK_CYCLIC_2D, CSRC_, CTXT_, DLEN_, DTYPE_,
      $                   LLD_, MB_, M_, NB_, N_, RSRC_
       PARAMETER          ( BLOCK_CYCLIC_2D = 1, DLEN_ = 9, DTYPE_ = 1,
@@ -381,20 +378,18 @@
       INTEGER            DESCA_1XP( 7 ), PARAM_CHECK( 7, 3 )
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           BLACS_GET, BLACS_GRIDEXIT, BLACS_GRIDINFO,
-     $                   DESC_CONVERT, GLOBCHK, PXERBLA, RESHAPE, SAXPY,
-     $                   SGEMM, SGERV2D, SGESD2D, SLACPY, SLATCPY,
-     $                   SPBTRF, SPOTRF, SSYRK, STBTRS, STRMM, STRRV2D,
-     $                   STRSD2D, STRSM, STRTRS
+      EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DESC_CONVERT,
+     $                   GLOBCHK, IGAMX2D, IGEBR2D, IGEBS2D, PXERBLA,
+     $                   RESHAPE, SDTTRF, SDTTRSV, SGERV2D, SGESD2D,
+     $                   STRRV2D, STRSD2D
 *     ..
 *     .. External Functions ..
-      LOGICAL            LSAME
       INTEGER            NUMROC
       REAL               SDOT
-      EXTERNAL           LSAME, NUMROC, SDOT
+      EXTERNAL           NUMROC, SDOT
 *     ..
 *     .. Intrinsic Functions ..
-      INTRINSIC          ICHAR, MIN, MOD
+      INTRINSIC          MOD, REAL
 *     ..
 *     .. Executable Statements ..
 *
@@ -408,18 +403,18 @@
       DESCA_1XP( 1 ) = 501
 *
       TEMP = DESCA( DTYPE_ )
-      IF( TEMP .EQ. 502 ) THEN
+      IF( TEMP.EQ.502 ) THEN
 *        Temporarily set the descriptor type to 1xP type
          DESCA( DTYPE_ ) = 501
-      ENDIF
+      END IF
 *
       CALL DESC_CONVERT( DESCA, DESCA_1XP, RETURN_CODE )
 *
       DESCA( DTYPE_ ) = TEMP
 *
-      IF( RETURN_CODE .NE. 0) THEN
-         INFO = -( 6*100 + 2 )
-      ENDIF
+      IF( RETURN_CODE.NE.0 ) THEN
+         INFO = -( 6*100+2 )
+      END IF
 *
 *     Get values out of descriptor for use in code.
 *
@@ -433,62 +428,58 @@
 *
 *
       CALL BLACS_GRIDINFO( ICTXT, NPROW, NPCOL, MYROW, MYCOL )
-      NP = NPROW * NPCOL
+      NP = NPROW*NPCOL
 *
 *
 *
-      IF( LWORK .LT. -1) THEN
+      IF( LWORK.LT.-1 ) THEN
          INFO = -10
-      ELSE IF ( LWORK .EQ. -1 ) THEN
+      ELSE IF( LWORK.EQ.-1 ) THEN
          IDUM3 = -1
       ELSE
          IDUM3 = 1
-      ENDIF
+      END IF
 *
-      IF( N .LT. 0 ) THEN
+      IF( N.LT.0 ) THEN
          INFO = -1
-      ENDIF
+      END IF
 *
-      IF( N+JA-1 .GT. STORE_N_A ) THEN
-         INFO = -( 6*100 + 6 )
-      ENDIF
+      IF( N+JA-1.GT.STORE_N_A ) THEN
+         INFO = -( 6*100+6 )
+      END IF
 *
 *     Argument checking that is specific to Divide & Conquer routine
 *
-      IF( NPROW .NE. 1 ) THEN
+      IF( NPROW.NE.1 ) THEN
          INFO = -( 6*100+2 )
-      ENDIF
+      END IF
 *
-      IF( N .GT. NP*NB-MOD( JA-1, NB )) THEN
+      IF( N.GT.NP*NB-MOD( JA-1, NB ) ) THEN
          INFO = -( 1 )
-         CALL PXERBLA( ICTXT,
-     $      'PSDTTRF, D&C alg.: only 1 block per proc',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PSDTTRF, D&C alg.: only 1 block per proc'
+     $                 , -INFO )
          RETURN
-      ENDIF
+      END IF
 *
-      IF((JA+N-1.GT.NB) .AND. ( NB.LT.2*INT_ONE )) THEN
+      IF( ( JA+N-1.GT.NB ) .AND. ( NB.LT.2*INT_ONE ) ) THEN
          INFO = -( 6*100+4 )
-         CALL PXERBLA( ICTXT,
-     $      'PSDTTRF, D&C alg.: NB too small',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PSDTTRF, D&C alg.: NB too small', -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *
 *     Check auxiliary storage size
 *
-      LAF_MIN = (12*NPCOL+3*NB)
+      LAF_MIN = ( 12*NPCOL+3*NB )
 *
-      IF( LAF .LT. LAF_MIN ) THEN
+      IF( LAF.LT.LAF_MIN ) THEN
          INFO = -8
 *        put minimum value of laf into AF( 1 )
          AF( 1 ) = LAF_MIN
-         CALL PXERBLA( ICTXT,
-     $      'PSDTTRF: auxiliary storage error ',
-     $      -INFO )
+         CALL PXERBLA( ICTXT, 'PSDTTRF: auxiliary storage error ',
+     $                 -INFO )
          RETURN
-      ENDIF
+      END IF
 *
 *     Check worksize
 *
@@ -496,33 +487,31 @@
 *
       WORK( 1 ) = WORK_SIZE_MIN
 *
-      IF( LWORK .LT. WORK_SIZE_MIN ) THEN
-         IF( LWORK .NE. -1 ) THEN
-           INFO = -10
-           CALL PXERBLA( ICTXT,
-     $      'PSDTTRF: worksize error ',
-     $      -INFO )
-         ENDIF
+      IF( LWORK.LT.WORK_SIZE_MIN ) THEN
+         IF( LWORK.NE.-1 ) THEN
+            INFO = -10
+            CALL PXERBLA( ICTXT, 'PSDTTRF: worksize error ', -INFO )
+         END IF
          RETURN
-      ENDIF
+      END IF
 *
 *     Pack params and positions into arrays for global consistency check
 *
-      PARAM_CHECK(  7, 1 ) = DESCA(5)
-      PARAM_CHECK(  6, 1 ) = DESCA(4)
-      PARAM_CHECK(  5, 1 ) = DESCA(3)
-      PARAM_CHECK(  4, 1 ) = DESCA(1)
-      PARAM_CHECK(  3, 1 ) = JA
-      PARAM_CHECK(  2, 1 ) = N
-      PARAM_CHECK(  1, 1 ) = IDUM3
+      PARAM_CHECK( 7, 1 ) = DESCA( 5 )
+      PARAM_CHECK( 6, 1 ) = DESCA( 4 )
+      PARAM_CHECK( 5, 1 ) = DESCA( 3 )
+      PARAM_CHECK( 4, 1 ) = DESCA( 1 )
+      PARAM_CHECK( 3, 1 ) = JA
+      PARAM_CHECK( 2, 1 ) = N
+      PARAM_CHECK( 1, 1 ) = IDUM3
 *
-      PARAM_CHECK(  7, 2 ) = 605
-      PARAM_CHECK(  6, 2 ) = 604
-      PARAM_CHECK(  5, 2 ) = 603
-      PARAM_CHECK(  4, 2 ) = 601
-      PARAM_CHECK(  3, 2 ) = 5
-      PARAM_CHECK(  2, 2 ) = 1
-      PARAM_CHECK(  1, 2 ) = 10
+      PARAM_CHECK( 7, 2 ) = 605
+      PARAM_CHECK( 6, 2 ) = 604
+      PARAM_CHECK( 5, 2 ) = 603
+      PARAM_CHECK( 4, 2 ) = 601
+      PARAM_CHECK( 3, 2 ) = 5
+      PARAM_CHECK( 2, 2 ) = 1
+      PARAM_CHECK( 1, 2 ) = 10
 *
 *     Want to find errors with MIN( ), so if no error, set it to a big
 *     number. If there already is an error, multiply by the the
@@ -533,20 +522,20 @@
       ELSE IF( INFO.LT.-DESCMULT ) THEN
          INFO = -INFO
       ELSE
-         INFO = -INFO * DESCMULT
+         INFO = -INFO*DESCMULT
       END IF
 *
 *     Check consistency across processors
 *
-      CALL GLOBCHK( ICTXT, 7, PARAM_CHECK, 7,
-     $              PARAM_CHECK( 1, 3 ), INFO )
+      CALL GLOBCHK( ICTXT, 7, PARAM_CHECK, 7, PARAM_CHECK( 1, 3 ),
+     $              INFO )
 *
 *     Prepare output: set info = 0 if no error, and divide by DESCMULT
 *     if error is not in a descriptor entry.
 *
       IF( INFO.EQ.BIGNUM ) THEN
          INFO = 0
-      ELSE IF( MOD( INFO, DESCMULT ) .EQ. 0 ) THEN
+      ELSE IF( MOD( INFO, DESCMULT ).EQ.0 ) THEN
          INFO = -INFO / DESCMULT
       ELSE
          INFO = -INFO
@@ -566,15 +555,15 @@
 *     Adjust addressing into matrix space to properly get into
 *        the beginning part of the relevant data
 *
-      PART_OFFSET = NB*( (JA-1)/(NPCOL*NB) )
+      PART_OFFSET = NB*( ( JA-1 ) / ( NPCOL*NB ) )
 *
-      IF ( (MYCOL-CSRC) .LT. (JA-PART_OFFSET-1)/NB ) THEN
+      IF( ( MYCOL-CSRC ).LT.( JA-PART_OFFSET-1 ) / NB ) THEN
          PART_OFFSET = PART_OFFSET + NB
-      ENDIF
+      END IF
 *
-      IF ( MYCOL .LT. CSRC ) THEN
+      IF( MYCOL.LT.CSRC ) THEN
          PART_OFFSET = PART_OFFSET - NB
-      ENDIF
+      END IF
 *
 *     Form a new BLACS grid (the "standard form" grid) with only procs
 *        holding part of the matrix, of size 1xNP where NP is adjusted,
@@ -582,7 +571,7 @@
 *
 *     First processor to hold part of the matrix:
 *
-      FIRST_PROC = MOD( ( JA-1 )/NB+CSRC, NPCOL )
+      FIRST_PROC = MOD( ( JA-1 ) / NB+CSRC, NPCOL )
 *
 *     Calculate new JA one while dropping off unused processors.
 *
@@ -591,12 +580,12 @@
 *     Save and compute new value of NP
 *
       NP_SAVE = NP
-      NP = ( JA_NEW+N-2 )/NB + 1
+      NP = ( JA_NEW+N-2 ) / NB + 1
 *
 *     Call utility routine that forms "standard-form" grid
 *
-      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE,
-     $              FIRST_PROC, INT_ONE, NP )
+      CALL RESHAPE( ICTXT, INT_ONE, ICTXT_NEW, INT_ONE, FIRST_PROC,
+     $              INT_ONE, NP )
 *
 *     Use new context from standard grid as context.
 *
@@ -610,9 +599,9 @@
 *
 *     Drop out processors that do not have part of the matrix.
 *
-      IF( MYROW .LT. 0 ) THEN
-         GOTO 1234
-      ENDIF
+      IF( MYROW.LT.0 ) THEN
+         GO TO 70
+      END IF
 *
 *     ********************************
 *     Values reused throughout routine
@@ -627,17 +616,17 @@
 *
 *     Offset in columns to beginning of main partition in each proc
 *
-      IF ( MYCOL .EQ. 0 ) THEN
-        PART_OFFSET = PART_OFFSET+MOD( JA_NEW-1, PART_SIZE )
-        MY_NUM_COLS = MY_NUM_COLS - MOD(JA_NEW-1, PART_SIZE )
-      ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         PART_OFFSET = PART_OFFSET + MOD( JA_NEW-1, PART_SIZE )
+         MY_NUM_COLS = MY_NUM_COLS - MOD( JA_NEW-1, PART_SIZE )
+      END IF
 *
 *     Size of main (or odd) partition in each processor
 *
       ODD_SIZE = MY_NUM_COLS
-      IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
          ODD_SIZE = ODD_SIZE - INT_ONE
-      ENDIF
+      END IF
 *
 *     Offset to workspace for Upper triangular factor
 *
@@ -646,9 +635,9 @@
 *
 *       Zero out space for fillin
 *
-        DO 10  I=1, LAF_MIN
-          AF( I ) = ZERO
-   10   CONTINUE
+      DO 10 I = 1, LAF_MIN
+         AF( I ) = ZERO
+   10 CONTINUE
 *
 *     Begin main code
 *
@@ -658,31 +647,31 @@
 ********************************************************************
 *
 *
-        IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
 *         Transfer last triangle D_i of local matrix to next processor
 *         which needs it to calculate fillin due to factorization of
 *         its main (odd) block A_i.
 *         Overlap the send with the factorization of A_i.
 *
-          CALL STRSD2D( ICTXT, 'U', 'N', 1, 1,
-     $                  DU( PART_OFFSET+ODD_SIZE+1 ), LLDA-1, 0,
-     $                  MYCOL+1 )
+         CALL STRSD2D( ICTXT, 'U', 'N', 1, 1,
+     $                 DU( PART_OFFSET+ODD_SIZE+1 ), LLDA-1, 0,
+     $                 MYCOL+1 )
 *
-        ENDIF
+      END IF
 *
 *
 *       Factor main partition A_i = L_i {U_i} in each processor
 *
-        CALL SDTTRF( ODD_SIZE, DL( PART_OFFSET+2 ), D( PART_OFFSET+1 ),
-     $                    DU( PART_OFFSET+1 ), INFO )
+      CALL SDTTRF( ODD_SIZE, DL( PART_OFFSET+2 ), D( PART_OFFSET+1 ),
+     $             DU( PART_OFFSET+1 ), INFO )
 *
-        IF( INFO.NE.0 ) THEN
-           INFO = MYCOL+1
-           GOTO 1500
-        ENDIF
+      IF( INFO.NE.0 ) THEN
+         INFO = MYCOL + 1
+         GO TO 20
+      END IF
 *
 *
-        IF ( MYCOL .LT. NP-1 ) THEN
+      IF( MYCOL.LT.NP-1 ) THEN
 *
 *         Apply factorization to lower connection block BL_i
 *         Apply factorization to upper connection block BU_i
@@ -691,103 +680,100 @@
 *         Perform the triangular solve {U_i}^T{BL'}_i^T = {BL_i}^T
 *
 *
-          DL( PART_OFFSET+ODD_SIZE+1 ) =
-     $            ( DL( PART_OFFSET+ODD_SIZE+1 ) )
-     $          / ( D( PART_OFFSET+ODD_SIZE ) )
+         DL( PART_OFFSET+ODD_SIZE+1 ) = ( DL( PART_OFFSET+ODD_SIZE+1 ) )
+     $                                   / ( D( PART_OFFSET+ODD_SIZE ) )
 *
 *
 *         Compute contribution to diagonal block(s) of reduced system.
 *          {C'}_i = {C_i}-{{BL'}_i}{{BU'}_i}
 *
 *
-          D( PART_OFFSET+ODD_SIZE+1 ) = D( PART_OFFSET+ODD_SIZE+1 )-
-     $       DL( PART_OFFSET+ODD_SIZE+1 )*DU( PART_OFFSET+ODD_SIZE )
+         D( PART_OFFSET+ODD_SIZE+1 ) = D( PART_OFFSET+ODD_SIZE+1 ) -
+     $                                 DL( PART_OFFSET+ODD_SIZE+1 )*
+     $                                 DU( PART_OFFSET+ODD_SIZE )
 *
-        ENDIF
+      END IF
 *       End of "if ( MYCOL .lt. NP-1 )..." loop
 *
 *
- 1500   CONTINUE
+   20 CONTINUE
 *       If the processor could not locally factor, it jumps here.
 *
-        IF ( MYCOL .NE. 0 ) THEN
+      IF( MYCOL.NE.0 ) THEN
 *
 *         Move entry that causes spike to auxiliary storage
 *
-          AF( WORK_U+1 ) = ( DL( PART_OFFSET+1 ) )
+         AF( WORK_U+1 ) = ( DL( PART_OFFSET+1 ) )
 *
-          IF (INFO.EQ.0) THEN
+         IF( INFO.EQ.0 ) THEN
 *
 *         Calculate the "spike" fillin, ${L_i} {{GU}_i} = {DL_i}$ .
 *
-          CALL SDTTRSV( 'L', 'N', ODD_SIZE, INT_ONE,
-     $                  DL( PART_OFFSET+2 ), D( PART_OFFSET+1 ),
-     $                  DU( PART_OFFSET+1 ), AF( WORK_U+1 ), ODD_SIZE,
-     $                  INFO )
+            CALL SDTTRSV( 'L', 'N', ODD_SIZE, INT_ONE,
+     $                    DL( PART_OFFSET+2 ), D( PART_OFFSET+1 ),
+     $                    DU( PART_OFFSET+1 ), AF( WORK_U+1 ), ODD_SIZE,
+     $                    INFO )
 *
 *
 *         Calculate the "spike" fillin, ${U_i}^T {{GL}_i}^T = {DU_i}^T$
 *
-          CALL STRRV2D( ICTXT, 'U', 'N', 1, 1, AF( 1 ), ODD_SIZE, 0,
-     $                  MYCOL-1 )
+            CALL STRRV2D( ICTXT, 'U', 'N', 1, 1, AF( 1 ), ODD_SIZE, 0,
+     $                    MYCOL-1 )
 *
-          CALL SDTTRSV( 'U', 'T', ODD_SIZE, INT_ONE,
-     $            DL( PART_OFFSET+2 ), D( PART_OFFSET+1 ),
-     $            DU( PART_OFFSET+1 ),
-     $            AF( 1 ), ODD_SIZE, INFO )
+            CALL SDTTRSV( 'U', 'T', ODD_SIZE, INT_ONE,
+     $                    DL( PART_OFFSET+2 ), D( PART_OFFSET+1 ),
+     $                    DU( PART_OFFSET+1 ), AF( 1 ), ODD_SIZE, INFO )
 *
 *
 *         Calculate the update block for previous proc, E_i = GL_i{GU_i}
 *
-          AF( ODD_SIZE+3 ) = -ONE *
-     $        SDOT( ODD_SIZE, AF( 1 ), 1, AF( WORK_U+1 ), 1 )
+            AF( ODD_SIZE+3 ) = -ONE*SDOT( ODD_SIZE, AF( 1 ), 1,
+     $                         AF( WORK_U+1 ), 1 )
 *
 *
 *         Initiate send of E_i to previous processor to overlap
 *           with next computation.
 *
-          CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+3 ),
-     $                  INT_ONE, 0, MYCOL-1 )
+            CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+3 ),
+     $                    INT_ONE, 0, MYCOL-1 )
 *
 *
-          IF ( MYCOL .LT. NP-1 ) THEN
+            IF( MYCOL.LT.NP-1 ) THEN
 *
 *           Calculate off-diagonal block(s) of reduced system.
 *           Note: for ease of use in solution of reduced system, store
 *           L's off-diagonal block in transpose form.
 *
-            AF( ODD_SIZE+1 ) = -ONE
-     $                         * ( DL( PART_OFFSET+ODD_SIZE+1 )
-     $                         * AF( WORK_U+ODD_SIZE ) )
+               AF( ODD_SIZE+1 ) = -ONE*( DL( PART_OFFSET+ODD_SIZE+1 )*
+     $                            AF( WORK_U+ODD_SIZE ) )
 *
 *
-            AF(WORK_U+(ODD_SIZE)+1 ) = -ONE
-     $                   * DU( PART_OFFSET+ODD_SIZE )
-     $                   * ( AF( ODD_SIZE ) )
+               AF( WORK_U+( ODD_SIZE )+1 ) = -ONE*
+     $            DU( PART_OFFSET+ODD_SIZE )*( AF( ODD_SIZE ) )
 *
-          ENDIF
+            END IF
 *
-        ENDIF
+         END IF
 *       End of "if ( MYCOL .ne. 0 )..."
 *
-        ENDIF
+      END IF
 *       End of "if (info.eq.0) then"
 *
 *
 *       Check to make sure no processors have found errors
 *
-        CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO,
-     $              -1, 0, 0 )
+      CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO, -1, 0,
+     $              0 )
 *
-        IF( MYCOL.EQ.0 ) THEN
-           CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
-        ELSE
-           CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
-        ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
+      ELSE
+         CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
+      END IF
 *
-        IF ( INFO.NE.0 ) THEN
-           GOTO 1000
-        ENDIF
+      IF( INFO.NE.0 ) THEN
+         GO TO 60
+      END IF
 *       No errors found, continue
 *
 *
@@ -800,46 +786,41 @@
 *
 *     The last processor does not participate in the factorization of
 *       the reduced system, having sent its E_i already.
-      IF( MYCOL .EQ. NPCOL-1 ) THEN
-        GOTO 14
-      ENDIF
+      IF( MYCOL.EQ.NPCOL-1 ) THEN
+         GO TO 50
+      END IF
 *
 *       Initiate send of off-diag block(s) to overlap with next part.
 *       Off-diagonal block needed on neighboring processor to start
 *       algorithm.
 *
-        IF( (MOD( MYCOL+1, 2 ) .EQ. 0) .AND. ( MYCOL .GT. 0 ) ) THEN
+      IF( ( MOD( MYCOL+1, 2 ).EQ.0 ) .AND. ( MYCOL.GT.0 ) ) THEN
 *
-          CALL SGESD2D( ICTXT, INT_ONE, INT_ONE,
-     $                       AF( ODD_SIZE+1 ),
-     $                       INT_ONE, 0, MYCOL-1 )
+         CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+1 ),
+     $                 INT_ONE, 0, MYCOL-1 )
 *
-          CALL SGESD2D( ICTXT, INT_ONE, INT_ONE,
-     $                       AF( WORK_U+ODD_SIZE+1 ),
-     $                       INT_ONE, 0, MYCOL-1 )
+         CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, AF( WORK_U+ODD_SIZE+1 ),
+     $                 INT_ONE, 0, MYCOL-1 )
 *
-        ENDIF
+      END IF
 *
 *       Copy last diagonal block into AF storage for subsequent
 *         operations.
 *
-        AF( ODD_SIZE+2 ) =
-     $        REAL( D( PART_OFFSET+ODD_SIZE+1 ) )
+      AF( ODD_SIZE+2 ) = REAL( D( PART_OFFSET+ODD_SIZE+1 ) )
 *
 *       Receive cont. to diagonal block that is stored on this proc.
 *
-        IF( MYCOL.LT. NPCOL-1 ) THEN
+      IF( MYCOL.LT.NPCOL-1 ) THEN
 *
-           CALL SGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $               AF( ODD_SIZE+2+1 ),
-     $               INT_ONE, 0,
-     $               MYCOL+1 )
+         CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+2+1 ),
+     $                 INT_ONE, 0, MYCOL+1 )
 *
 *          Add contribution to diagonal block
 *
-           AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 )+AF( ODD_SIZE+3 )
+         AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 ) + AF( ODD_SIZE+3 )
 *
-        ENDIF
+      END IF
 *
 *
 *       *************************************
@@ -847,98 +828,96 @@
 *
 *       The distance for sending and receiving for each level starts
 *         at 1 for the first level.
-        LEVEL_DIST = 1
+      LEVEL_DIST = 1
 *
 *       Do until this proc is needed to modify other procs' equations
 *
-   12   CONTINUE
-        IF( MOD( (MYCOL+1)/LEVEL_DIST, 2) .NE. 0 ) GOTO 11
+   30 CONTINUE
+      IF( MOD( ( MYCOL+1 ) / LEVEL_DIST, 2 ).NE.0 )
+     $   GO TO 40
 *
 *         Receive and add contribution to diagonal block from the left
 *
-          IF( MYCOL-LEVEL_DIST .GE. 0 ) THEN
-            CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ),
-     $                     INT_ONE, 0, MYCOL-LEVEL_DIST )
+      IF( MYCOL-LEVEL_DIST.GE.0 ) THEN
+         CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL-LEVEL_DIST )
 *
-            AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 )+WORK( 1 )
+         AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 ) + WORK( 1 )
 *
-          ENDIF
+      END IF
 *
 *         Receive and add contribution to diagonal block from the right
 *
-          IF( MYCOL+LEVEL_DIST .LT. NPCOL-1 ) THEN
-            CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ),
-     $                        INT_ONE, 0, MYCOL+LEVEL_DIST )
+      IF( MYCOL+LEVEL_DIST.LT.NPCOL-1 ) THEN
+         CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL+LEVEL_DIST )
 *
-            AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 )+WORK( 1 )
+         AF( ODD_SIZE+2 ) = AF( ODD_SIZE+2 ) + WORK( 1 )
 *
-          ENDIF
+      END IF
 *
-          LEVEL_DIST = LEVEL_DIST*2
+      LEVEL_DIST = LEVEL_DIST*2
 *
-        GOTO 12
-   11   CONTINUE
+      GO TO 30
+   40 CONTINUE
 *       [End of GOTO Loop]
 *
 *
 *       *********************************
 *       Calculate and use this proc's blocks to modify other procs'...
-        IF( AF( ODD_SIZE+2 ) .EQ. ZERO ) THEN
-               INFO = NPCOL + MYCOL
-        ENDIF
+      IF( AF( ODD_SIZE+2 ).EQ.ZERO ) THEN
+         INFO = NPCOL + MYCOL
+      END IF
 *
 *       ****************************************************************
 *       Receive offdiagonal block from processor to right.
 *         If this is the first group of processors, the receive comes
 *         from a different processor than otherwise.
 *
-        IF( LEVEL_DIST .EQ. 1 )THEN
-          COMM_PROC = MYCOL + 1
+      IF( LEVEL_DIST.EQ.1 ) THEN
+         COMM_PROC = MYCOL + 1
 *
 *           Move block into place that it will be expected to be for
 *             calcs.
 *
-          AF( WORK_U+ODD_SIZE+3 ) = AF( ODD_SIZE+1 )
+         AF( WORK_U+ODD_SIZE+3 ) = AF( ODD_SIZE+1 )
 *
-          AF( ODD_SIZE+3 ) = AF( WORK_U+ODD_SIZE+1 )
+         AF( ODD_SIZE+3 ) = AF( WORK_U+ODD_SIZE+1 )
 *
-        ELSE
-          COMM_PROC = MYCOL + LEVEL_DIST/2
-        ENDIF
+      ELSE
+         COMM_PROC = MYCOL + LEVEL_DIST / 2
+      END IF
 *
-        IF( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-2 )THEN
+      IF( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-2 ) THEN
 *
-          CALL SGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $        AF( ODD_SIZE+1 ),
-     $                       INT_ONE, 0, COMM_PROC )
+         CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+1 ),
+     $                 INT_ONE, 0, COMM_PROC )
 *
-          CALL SGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $        AF( WORK_U+ODD_SIZE+1 ),
-     $                       INT_ONE, 0, COMM_PROC )
+         CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, AF( WORK_U+ODD_SIZE+1 ),
+     $                 INT_ONE, 0, COMM_PROC )
 *
-          IF( INFO .EQ. 0 ) THEN
+         IF( INFO.EQ.0 ) THEN
 *
 *
 *         Modify lower off_diagonal block with diagonal block
 *
 *
-          AF( ODD_SIZE+1 ) = AF( ODD_SIZE+1 )
-     $                 / ( AF( ODD_SIZE+2 ) )
+            AF( ODD_SIZE+1 ) = AF( ODD_SIZE+1 ) / ( AF( ODD_SIZE+2 ) )
 *
-          ENDIF
+         END IF
 *         End of "if ( info.eq.0 ) then"
 *
 *         Calculate contribution from this block to next diagonal block
 *
-          WORK( 1 ) = -ONE*( AF( ODD_SIZE+1 ) )*
-     $                AF( WORK_U+(ODD_SIZE)+1 )
+         WORK( 1 ) = -ONE*( AF( ODD_SIZE+1 ) )*
+     $               AF( WORK_U+( ODD_SIZE )+1 )
 *
 *         Send contribution to diagonal block's owning processor.
 *
-          CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE,
-     $                     0, MYCOL+LEVEL_DIST )
+         CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL+LEVEL_DIST )
 *
-        ENDIF
+      END IF
 *       End of "if( mycol/level_dist .le. (npcol-1)/level_dist-2 )..."
 *
 *
@@ -946,98 +925,95 @@
 *       Receive off_diagonal block from left and use to finish with this
 *         processor.
 *
-        IF( (MYCOL/LEVEL_DIST .GT. 0 ).AND.
-     $      ( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-1 ) ) THEN
+      IF( ( MYCOL / LEVEL_DIST.GT.0 ) .AND.
+     $    ( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-1 ) ) THEN
 *
-          IF( LEVEL_DIST .GT. 1)THEN
+         IF( LEVEL_DIST.GT.1 ) THEN
 *
-*           Receive offdiagonal block(s) from proc level_dist/2 to the left
+*           Receive offdiagonal block(s) from proc level_dist/2 to the
+*           left
 *
-           CALL SGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $            AF( WORK_U+ODD_SIZE+2+1 ),
-     $            INT_ONE, 0, MYCOL-LEVEL_DIST/2 )
+            CALL SGERV2D( ICTXT, INT_ONE, INT_ONE,
+     $                    AF( WORK_U+ODD_SIZE+2+1 ), INT_ONE, 0,
+     $                    MYCOL-LEVEL_DIST / 2 )
 *
-*           Receive offdiagonal block(s) from proc level_dist/2 to the left
+*           Receive offdiagonal block(s) from proc level_dist/2 to the
+*           left
 *
-           CALL SGERV2D( ICTXT, INT_ONE, INT_ONE,
-     $            AF( ODD_SIZE+2+1 ),
-     $            INT_ONE, 0, MYCOL-LEVEL_DIST/2 )
+            CALL SGERV2D( ICTXT, INT_ONE, INT_ONE, AF( ODD_SIZE+2+1 ),
+     $                    INT_ONE, 0, MYCOL-LEVEL_DIST / 2 )
 *
-          ENDIF
+         END IF
 *
 *
-          IF( INFO.EQ.0 ) THEN
+         IF( INFO.EQ.0 ) THEN
 *
 *         Use diagonal block(s) to modify this offdiagonal block
 *
-          AF( ODD_SIZE+3 ) = AF( ODD_SIZE+3 )
-     $         / ( AF( ODD_SIZE+2 ) )
+            AF( ODD_SIZE+3 ) = AF( ODD_SIZE+3 ) / ( AF( ODD_SIZE+2 ) )
 *
 *
-          ENDIF
+         END IF
 *         End of "if( info.eq.0 ) then"
 *
 *         Use offdiag block(s) to calculate modification to diag block
 *           of processor to the left
 *
-          WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )
-     $              *( AF( WORK_U+ODD_SIZE+3 ) )
+         WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )*( AF( WORK_U+ODD_SIZE+3 ) )
 *
 *         Send contribution to diagonal block's owning processor.
 *
-          CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE,
-     $                     0, MYCOL-LEVEL_DIST )
+         CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE, 0,
+     $                 MYCOL-LEVEL_DIST )
 *
 *         *******************************************************
 *
-          IF( MYCOL/LEVEL_DIST .LE. (NPCOL-1)/LEVEL_DIST-2 ) THEN
+         IF( MYCOL / LEVEL_DIST.LE.( NPCOL-1 ) / LEVEL_DIST-2 ) THEN
 *
 *           Decide which processor offdiagonal block(s) goes to
 *
-            IF( ( MOD( MYCOL/( 2*LEVEL_DIST ),2 )) .EQ.0 ) THEN
-              COMM_PROC = MYCOL + LEVEL_DIST
+            IF( ( MOD( MYCOL / ( 2*LEVEL_DIST ), 2 ) ).EQ.0 ) THEN
+               COMM_PROC = MYCOL + LEVEL_DIST
             ELSE
-              COMM_PROC = MYCOL - LEVEL_DIST
-            ENDIF
+               COMM_PROC = MYCOL - LEVEL_DIST
+            END IF
 *
 *           Use offdiagonal blocks to calculate offdiag
 *             block to send to neighboring processor. Depending
 *             on circumstances, may need to transpose the matrix.
 *
-              WORK( 1 ) = -ONE*AF( WORK_U+ODD_SIZE+3 )
-     $                  * AF( ODD_SIZE+1 )
+            WORK( 1 ) = -ONE*AF( WORK_U+ODD_SIZE+3 )*AF( ODD_SIZE+1 )
 *
 *           Send contribution to offdiagonal block's owning processor.
 *
             CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE,
-     $                         0, COMM_PROC )
+     $                    0, COMM_PROC )
 *
-              WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )
-     $                  * AF( WORK_U+ODD_SIZE+1 )
+            WORK( 1 ) = -ONE*AF( ODD_SIZE+3 )*AF( WORK_U+ODD_SIZE+1 )
 *
 *           Send contribution to offdiagonal block's owning processor.
 *
             CALL SGESD2D( ICTXT, INT_ONE, INT_ONE, WORK( 1 ), INT_ONE,
-     $                         0, COMM_PROC )
+     $                    0, COMM_PROC )
 *
-          ENDIF
+         END IF
 *
-        ENDIF
+      END IF
 *       End of "if( mycol/level_dist.le. (npcol-1)/level_dist -1 )..."
 *
-   14   CONTINUE
+   50 CONTINUE
 *
 *
- 1000 CONTINUE
+   60 CONTINUE
 *
 *
 *     Free BLACS space used to hold standard-form grid.
 *
-      IF( ICTXT_SAVE .NE. ICTXT_NEW ) THEN
+      IF( ICTXT_SAVE.NE.ICTXT_NEW ) THEN
          CALL BLACS_GRIDEXIT( ICTXT_NEW )
-      ENDIF
+      END IF
 *
- 1234 CONTINUE
+   70 CONTINUE
 *
 *     Restore saved input parameters
 *
@@ -1050,14 +1026,14 @@
 *
 *         Make INFO consistent across processors
 *
-          CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO,
-     $              -1, 0, 0 )
+      CALL IGAMX2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, INFO, INFO, -1, 0,
+     $              0 )
 *
-          IF( MYCOL.EQ.0 ) THEN
-             CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
-          ELSE
-             CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
-          ENDIF
+      IF( MYCOL.EQ.0 ) THEN
+         CALL IGEBS2D( ICTXT, 'A', ' ', 1, 1, INFO, 1 )
+      ELSE
+         CALL IGEBR2D( ICTXT, 'A', ' ', 1, 1, INFO, 1, 0, 0 )
+      END IF
 *
 *
       RETURN
