@@ -1,10 +1,9 @@
       SUBROUTINE PSPBTRSV( UPLO, TRANS, N, BW, NRHS, A, JA, DESCA, B,
      $                     IB, DESCB, AF, LAF, WORK, LWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     April 3, 2000
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS, UPLO
@@ -395,7 +394,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDEXIT, BLACS_GRIDINFO, DESC_CONVERT,
      $                   GLOBCHK, PXERBLA, RESHAPE, SGEMM, SGERV2D,
-     $                   SGESD2D, SLACPY, SMATADD, STBTRS, STRMM, STRTRS
+     $                   SGESD2D, SLAMOV, SMATADD, STBTRS, STRMM, STRTRS
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -761,7 +760,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-               CALL SLACPY( 'N', BW, NRHS,
+               CALL SLAMOV( 'N', BW, NRHS,
      $                      B( PART_OFFSET+ODD_SIZE-BW+1 ), LLDB,
      $                      WORK( 1 ), BW )
 *
@@ -1085,7 +1084,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-               CALL SLACPY( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
+               CALL SLAMOV( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
      $                      LLDB, WORK( 1+BW-BW ), BW )
 *
                CALL STRMM( 'L', 'U', 'T', 'N', BW, NRHS, -ONE,
@@ -1135,7 +1134,7 @@
 *           First copy and multiply it into temporary storage,
 *             then use it on RHS
 *
-               CALL SLACPY( 'N', BW, NRHS,
+               CALL SLAMOV( 'N', BW, NRHS,
      $                      B( PART_OFFSET+ODD_SIZE-BW+1 ), LLDB,
      $                      WORK( 1 ), BW )
 *
@@ -1459,7 +1458,7 @@
 *         First copy and multiply it into temporary storage,
 *           then use it on RHS
 *
-               CALL SLACPY( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
+               CALL SLAMOV( 'N', BW, NRHS, B( PART_OFFSET+ODD_SIZE+1 ),
      $                      LLDB, WORK( 1+BW-BW ), BW )
 *
                CALL STRMM( 'L', 'L', 'N', 'N', BW, NRHS, -ONE,
