@@ -1,10 +1,9 @@
       SUBROUTINE PZLARFB( SIDE, TRANS, DIRECT, STOREV, M, N, K, V, IV,
      $                    JV, DESCV, T, C, IC, JC, DESCC, WORK )
 *
-*  -- ScaLAPACK auxiliary routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     May 1, 1997
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          SIDE, TRANS, DIRECT, STOREV
@@ -238,7 +237,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GRIDINFO, INFOG1L, INFOG2L, PB_TOPGET,
      $                   PBZTRAN, ZGEBR2D, ZGEBS2D, ZGEMM,
-     $                   ZGSUM2D, ZLACPY, ZLASET, ZTRBR2D,
+     $                   ZGSUM2D, ZLAMOV, ZLASET, ZTRBR2D,
      $                   ZTRBS2D, ZTRMM
 *     ..
 *     .. Intrinsic Functions ..
@@ -325,7 +324,7 @@
                IF( MYROW.EQ.IVROW )
      $            CALL ZTRBS2D( ICTXT, 'Rowwise', ROWBTOP, UPLO,
      $                          'Non unit', K, K, T, NBV )
-               CALL ZLACPY( 'All', MPC, K, V( IOFFV ), LDV, WORK( IPV ),
+               CALL ZLAMOV( 'All', MPC, K, V( IOFFV ), LDV, WORK( IPV ),
      $                      LV )
             ELSE
                CALL ZGEBR2D( ICTXT, 'Rowwise', ROWBTOP, MPC, K,
@@ -462,11 +461,11 @@
                   CALL ZLASET( 'All', IROFFV, K, ZERO, ZERO,
      $                         WORK( IPW ), LW )
                   IPW1 = IPW + IROFFV
-                  CALL ZLACPY( 'All', NPV, K, V( IOFFV ), LDV,
+                  CALL ZLAMOV( 'All', NPV, K, V( IOFFV ), LDV,
      $                         WORK( IPW1 ), LW )
                ELSE
                   IPW1 = IPW
-                  CALL ZLACPY( 'All', NPV, K, V( IOFFV ), LDV,
+                  CALL ZLAMOV( 'All', NPV, K, V( IOFFV ), LDV,
      $                         WORK( IPW1 ), LW )
                END IF
 *
@@ -626,11 +625,11 @@
                   CALL ZLASET( 'All', K, ICOFFV, ZERO, ZERO,
      $                         WORK( IPW ), LW )
                   IPW1 = IPW + ICOFFV * LW
-                  CALL ZLACPY( 'All', K, MQV, V( IOFFV ), LDV,
+                  CALL ZLAMOV( 'All', K, MQV, V( IOFFV ), LDV,
      $                         WORK( IPW1 ), LW )
                ELSE
                   IPW1 = IPW
-                  CALL ZLACPY( 'All', K, MQV, V( IOFFV ), LDV,
+                  CALL ZLAMOV( 'All', K, MQV, V( IOFFV ), LDV,
      $                         WORK( IPW1 ), LW )
                END IF
 *
@@ -775,7 +774,7 @@
                IF( MYCOL.EQ.IVCOL )
      $            CALL ZTRBS2D( ICTXT, 'Columnwise', COLBTOP, UPLO,
      $                          'Non unit', K, K, T, MBV )
-               CALL ZLACPY( 'All', K, NQC, V( IOFFV ), LDV, WORK( IPV ),
+               CALL ZLAMOV( 'All', K, NQC, V( IOFFV ), LDV, WORK( IPV ),
      $                      LV )
             ELSE
                CALL ZGEBR2D( ICTXT, 'Columnwise', COLBTOP, K, NQC,
