@@ -3,10 +3,10 @@
      $                    DESCB, X, IX, JX, DESCX, RCOND, FERR, BERR,
      $                    WORK, LWORK, RWORK, LRWORK, INFO )
 *
-*  -- ScaLAPACK routine (version 1.5) --
+*  -- ScaLAPACK routine (version 1.7) --
 *     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
 *     and University of California, Berkeley.
-*     May 1, 1997
+*     December 31, 1998
 *
 *     .. Scalar Arguments ..
       CHARACTER          EQUED, FACT, UPLO
@@ -422,7 +422,7 @@
             NP = NUMROC( N+IROFFA, DESCA( MB_ ), MYROW, IAROW, NPROW )
             IF( MYROW.EQ.IAROW )
      $         NP = NP-IROFFA
-            NQ = NUMROC( N+ICOFFA, DESCB( NB_ ), MYCOL, IACOL, NPCOL )
+            NQ = NUMROC( N+ICOFFA, DESCA( NB_ ), MYCOL, IACOL, NPCOL )
             IF( MYCOL.EQ.IACOL )
      $         NQ = NQ-ICOFFA
             LWMIN = 3*DESCA( LLD_ )
