@@ -1,12 +1,9 @@
       SUBROUTINE PZPTTRSV( UPLO, TRANS, N, NRHS, D, E, JA, DESCA, B, IB,
      $                     DESCB, AF, LAF, WORK, LWORK, INFO )
 *
-*
-*
-*  -- ScaLAPACK routine (version 1.7) --
-*     University of Tennessee, Knoxville, Oak Ridge National Laboratory,
-*     and University of California, Berkeley.
-*     November 15, 1997
+*  -- ScaLAPACK routine (version 2.0.2) --
+*     Univ. of Tennessee, Univ. of California Berkeley, Univ. of Colorado Denver
+*     May 1 2012
 *
 *     .. Scalar Arguments ..
       CHARACTER          TRANS, UPLO
@@ -410,7 +407,7 @@
 *     .. External Subroutines ..
       EXTERNAL           BLACS_GET, BLACS_GRIDEXIT, BLACS_GRIDINFO,
      $                   DESC_CONVERT, GLOBCHK, PXERBLA, RESHAPE, ZGEMM,
-     $                   ZGERV2D, ZGESD2D, ZLACPY, ZMATADD, ZTBTRS,
+     $                   ZGERV2D, ZGESD2D, ZLAMOV, ZMATADD, ZTBTRS,
      $                   ZTRMM, ZTRTRS
 *     ..
 *     .. External Functions ..
