@@ -107,6 +107,8 @@
 *     ..
 *     .. Executable Statements ..
 *
+	ICPY = 0
+*	
 *     Get grid parameters.
 *
       CALL BLACS_GRIDINFO( ICTXT, NPROW, NPCOL, MYROW, MYCOL )
